title: Paradoxes et enjeux environnementaux de la numérisation
url: https://gauthierroussilhe.com/post/paradoxes-enjeux.html
hash_url: 8b4951ac1a12fd9431861f49af5886c8

<p>
    Cela fait un peu moins de 4 ans que j’ai commencé à travailler sur la question des impacts environnementaux du secteur numérique. Durant ces quelques années, j’ai pu contribuer de façon très modeste à la recherche et au discours public. J’ai assisté ou participé à des réunions entre différents acteurs privés et publics (comité d’experts, ateliers internes, commissions, etc..) où j’ai pu observé un jeu complexe autour du rapprochement entre numérique et écologie. Alors que le sujet est en train de finir une nouvelle phase législative avec le projet de loi étudié en Parlement, il me semble intéressant de partager quelques observations et perspectives. Ce point d’étape est d’autant plus nécessaire que la fin de cette phase législative indique une nouvelle appropriation du sujet par des acteurs économiques plus ou moins importants, prêts à se partager les budgets débloqués et les nouvelles “opportunités d’affaire”. Cette appropriation peut déformer durablement le sujet initial, il est donc important de bien définir où se situent les valeurs et les frontières de ce champ. Cette rétrospective s’organisera en plusieurs articles afin d’aller traiter des grandes thématiques : une vision globale sur les paradoxes et les enjeux du sujet (ici), <a href="limites-debat.html" rel="noopener noreferrer" target="_blank">les limites du débat</a>, une critique et <a href="ecoconception-critique.html" rel="noopener noreferrer" target="_blank">des conseils sur l’éco-conception numérique</a>, et finalement <a href="territoires-centres-de-donnees.html" rel="noopener noreferrer" target="_blank">des perspectives de recherche possiblement plus fertiles</a>.
</p>

<h3>Table des matières</h3>
<a href="#paradoxe">Curieux paradoxes</a><br/>
<a href="#conseil">Quelques conseils de recherche</a><br/>
<a href="#prospective">Intuitions</a><br/>
<a href="#mettrefin">Mettre fin au régime d'exception</a><br/>
<br/>

<h3 id="paradoxe">Curieux paradoxes</h3>

<p>
    Mon travail consiste en partie à comprendre et décrire la structuration matérielle du secteur numérique dans le cadre de la transition écologique. À ce titre, j’ai pu relever plusieurs paradoxes qui me semblent important de partager. Ces paradoxes ne sont pas forcément solvables dans la situation actuelle. Cependant, l’absence de solution n’empêche pas de reconnaître leur présence et déterminer des stratégies de contournement pour les désamorcer à long-terme.
</p>

<p>
    Lorsqu’on “hérite” du secteur numérique d’un point de vue environnemental, il me semble qu’il y a deux grands mouvements à opérer : déconstruire le discours de la dématérialisation qui accompagne ce secteur depuis 30 ans – cela implique de bien décrire les conditions matérielles des infrastructures et des services numériques ; contre les hypothèses “anti-géographiques” comme le concept de village global emprunté à Marshall McLuhan qui impliquerait que les réseaux de communication nous permettraient de faire disparaitre les distances et de créer un espace unique et indifférencié, sans histoire et sans géographie – cela implique alors de “territorialiser” la matérialité du numérique : les infrastructures numériques ne sont pas également réparties sur Terre et agissent dans des territoires précis où elles concentrent leurs impacts.
</p>

<h4>Empreinte globale et territorialisation</h4>
<p>
    Avec le temps j’en suis venu à estimer que <b>l’estimation globale de l’empreinte environnementale du secteur numérique ne vise pas tant à contrer les discours de dématérialisation et antigéographiques du secteur, mais d’une certaine façon les poursuit</b>. Je m’explique : les estimations globales produites portent généralement sur des tiers techniques (<i>data centers</i>, réseaux de transmission, équipements utilisateurs) et des facteurs d’impact (consommation d’énergie primaire ou d’électricité, émissions de gaz à effet de serre, consommation d’eau et de ressources). Toutefois, quand on dit, par exemple, que les <i>data centers</i> représentent 1% de la consommation d’électricité mondiale ou que le secteur numérique émet 2 à 4% des émissions mondiales de gaz à effet de serre on ne dit pas grand chose finalement car on ne dit pas où et de quelle façon. N’importe quel chiffre global présuppose que la pression s’exerce de façon uniforme sur un globe où se perpétue alors une vision éthérée et non-géographique des activités numériques. En fait, les 1% de consommation d’électricité des <i>data centers</i> sont peu au niveau global mais sont très concentrés dans certaines zones. Si on préfère approcher la question via un méthode territoriale on peut enfin comprendre que la demande d’énergie des <i>data centers</i> est très concentrée et pose de réelles questions d’aménagement urbain pour de nombreuses villes en Europe ou aux États-Unis : schéma de distribution électrique, réseaux d'eau, artifilisation des sols, etc. Dans un monde idéal, une estimation globale devrait toujours être accompagnée d’une mise en situation territoriale (donc des données qualitatives) afin de comprendre concrètement les enjeux face à nous. C’est un changement de méthode que je précise dans <a href="territoires-centres-de-donnees.html" rel="noopener noreferrer" target="_blank">le quatrième article de cette série</a>.

</p>

<h4>Obtenir des données environnementales</h4>
<p>
    Un des plus gros problèmes lorsqu’on essaye de modéliser l’empreinte environnementale du secteur numérique c’est la disponibilité et l’existence des données sur le sujet. <b>Les chaines de production, d’approvisionnement et de distribution, et les infrastructures du numérique sont structurellement opaques</b> et ce pour plusieurs raisons. Premièrement, la complexité des appareils fabriqués augmente largement le nombre de fournisseurs impliqués. Là où certaines infrastructures demandent peu de matériaux différents mais en grande quantité, le fabrication de systèmes numériques demande de nombreux métaux différents mais dans des quantités relativement moyennes (sauf pour les grands métaux). 50 métaux dans un smartphone c’est presque autant de fournisseurs qui sous-traitent à d’autres personnes qui sous-traitent à d'autres personnes, etc… Depuis 2013, Fairphone a difficilement réussi à remonter les chaines d'approvisionnement de 10 métaux utilisés pour leur smartphone. Deuxièmement, la sous-traitance mentionnée plus haut est le résultat d’une course au moins-disant imposée par les géants du secteur qui souhaitent réduire et maitriser leur coûts au maximum. Dans un iPhone 6, les matières premières représentent un coût de 1,03 $ <a href="https://www.statista.com/chart/10719/materials-used-in-iphone-6/" rel="noopener noreferrer" target="_blank">d'après 911 Metallurgist</a>. On peut donc difficilement imaginer que leur extraction puisse se faire avec un grand soin et en toute considération des limites planétaires. Troisièmement, c’est un secteur hyper-concurrentiel où les grands acteurs placent la plupart de leurs données sous clause de confidentialité. <b>L'agrégation des données reste aussi un bon moyen de rendre les données inexploitables car ce n’est pas tant la somme de l’addition qui est intéressante dans notre domaine mais les éléments additionnés et leur détermination individuelle</b>. 
</p>

<!--            <p>
    Quel serait alors le prix de la transparence et de la remontée des données ? Jusqu’à présent j’ai rencontré peu d’acteurs qui étaient optimistes sur l’ouverture à court terme des données environnementales du secteur. À défaut d'ouverture réelle des données, il s’agirait alors de réduire la taille des chaines de production et d’approvisionnement et donc d’augmenter le coût unitaire des matériaux et, <i>in fine</i>, des composants. Voici notre seconde paradoxe, <b>des chaines d’approvisionnement opaques et mondialisées sont le résultat de modèles économiques agressifs. Le prix de l’obtention et de la transparence des données sera des chaines d’approvisionnement moins étendues et plus chères, des garanties nationales d’achat, et un rapatriement des impacts environnementaux plus près de chez nous (crassiers, pollutions des milieux, etc.)</b>. Guillaume Pitron évoquait déjà ce constat il y a quelques années dans "La Guerre des métaux rares". Néanmoins, les technologies numériques, telles qu’elles ont été historiquement structurées, restent résolument globales. Rendre local la chaine opératoire (au sens anthropologique) d’un système numérique demande un effort conséquent et donc des contraintes originales (ruptures d’approvisionnement, nouvelle donne sociale et/ou écologique, etc.) difficiles à imaginer aujourd’hui. C’est le constat que nous rappelle Ulrich Brand dans son dernier livre “The Imperial Way of Living” : le mode de vie “moderne” (abondance matérielle, etc.) requiert plus d’espace que celui définit par nos frontières et nécessite donc l’exploitation de ressources et d’humains à l’extérieur de l’espace national : un empire. En ce sens, le développement actuel du numérique et son opacité structurelle perpétue nos modes de vie “impériaux”. 
</p>
-->

<h4>Numérique jetable et durable</h4>
<p>
     Si l’on s’intéresse à réduire l’empreinte écologique du secteur numérique on comprend assez rapidement qu’il faut produire moins d’équipements et les faire durer le plus longtemps possible. Il faut donc favoriser la standardisation des composants, la réparabilité des appareils et la distribution des savoirs techniques. Pour le dire différemment, on déduit qu’il faut prendre soin des systèmes numériques et que cela est finalement proche d’autres pratiques dans l’informatique (logiciel libre, réseaux auto-gérés, etc.). <b>Ce “prendre soin” implique, me semble t-il, deux choses : un relatif abandon de la course à la puissance (informatique et/ou managériale), les systèmes durables s’accommodent rarement de systèmes uniquement taillés pour la puissance et la, toujours éphèmère, performance maximum ; et une certaine technophilie, dans le sens où on apprécie ces systèmes non pas pour les discours majoritaires aujourd’hui (progrès technique, contrôle et puissance) mais pour les outils fragiles qu’ils sont</b>. Cette connaissance de leur fragilité devrait amener à ne pas forcer l’adoption de ces systèmes dans tous les contextes, surtout ceux dans lesquels ils n’ont pas de pertinence concrète. <b>“Prendre soin” des systèmes numériques pourrait potentiellement s’opposer au projet de tout-numérisation (forcer la numérisation de toutes les activités dans tous les contextes)</b>.
</p>

<figure class="img-figure-large"><div class="img-wrapper" style="padding-bottom: 65%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-paradoxes-02.jpg"></div><figcaption>Nouveaux possesseurs d'un iPhone XS à Sydney (Crédit : The Sun)</figcaption></figure>

<p>
    De nombreuses personnes se réclament technophiles car elles s’équipent régulièrement des dernières générations d’appareils numériques (smartphones, montres, enceintes, téléviseurs, etc.). Il ne me semble pas que ces actions témoignent d’une certaine affection des systèmes numériques mais plutôt d’une affection pour la praticité qu’apportent ces systèmes et parfois sur ce que la possession de ces appareils disent sur leur possesseur (statut social, etc.). Dans ce cas leur renouvellement est banal et leur “jetabilité” inscrite dans leur usage. Voilà, un paradoxe intéressant : <b>ceux qui pourraient réclamer une certaine forme de technophilie, une technophilie de consommation et de puissance, sont potentiellement ceux qui participent à perpétuer un numérique “jetable”, contribuant ainsi à la mise à mort prématurée des systèmes numériques, bien loin de leur amour annoncé</b>.
</p>

<h4>Droits numériques des non-numérisés</h4>
<p>
    Je souhaiterais terminer cette première liste avec un dernier paradoxe qui reprend ce qui a été dit plus haut. On parle souvent de “droit numérique” ou <i>digital rights</i> pour garantir un accès égal aux réseaux et aux services numériques, le respect de la vie privée des internautes, la lutte contre la censure, etc. Cependant, est-ce que le droit numérique ne devrait pas en creux défendre les droits de ceux qui ne souhaitent pas utiliser des moyens numériques ? Si un service public essentiel est entièrement numérisé (absence d’espaces physiques de médiation et d'accès), qui défend les droits de ceux qui veulent accéder au service par un moyen conventionnel ? Qui garantit que la numérisation d’un service n’amène pas à sa disparition physique et donc à sa disparition pour tous ceux qui n’ont pas les moyens pratiques de connexion, les moyens socio-économiques et culturels, ou parce que des conditions locales ne le permettent pas ? Les récentes inondations à Zhengzhou en Chine a fait tombé une partie du réseau internet locale, <a href="https://gnews.org/1416347/" rel="noopener noreferrer" target="_blank">bloquant les paiements quotidiens via Alipay, l'accès à des vélos via QR</a>, etc. <b>Donc, est-ce le droit numérique sert aussi à assurer que des citoyens ont toujours une alternative crédible à tout service ou produit entièrement numérisé ?</b> En même titre que le code de la route régit les règles de circulation et la relation entre véhicules de tout type (vélo, voiture,…) sur des routes variées, est-ce que le droit numérique devrait régir l’accès de plein droit à ceux qui ont choisi de naviguer différemment ?  
</p>


<h3 id="conseil">Quelques conseils de recherche</h3>

<p>
    Au-delà de dessiner les contours de certains paradoxes du secteur numérique, il est important de donner quelques conseils sur la façon d’approcher la recherche sur ce sujet, que l’on fasse par curiosité ou passion ou dans le cas d’une recherche académique.
</p>

<h4>Une étude de cas n’est pas de la recherche empirique</h4>
<p>
    Le secteur numérique comprend une multitude d’acteurs avec d’importants moyens et notamment les moyens de relayer leur propre recherche académique, ou non-académique, ou leurs publications. Face à l’absence de données ouvertes on peut être tenté d’utiliser les études de cas fournies par des équipementiers, des entreprises de conseil ou autres. <b>Il faut toutefois rappeler que les études de cas professionnelles ne sont pas de la recherche empirique et ne sont pas soumis au processus de publication scientifique</b>. De plus, ces études de cas ont aussi pour objet de mettre en valeur le déploiement de tel ou tel système dans une optique de promotion. Les aspects plus opaques du déploiement, la maintenance ou même l’usage dans le temps du système en question sont rarement remontés. Finalement, une étude de cas ne peut pas être utilisée pour extrapoler les conséquences du déploiement d’un système car chaque contexte de déploiement est trop particulier (culture, langue, ressources, management, etc.) pour être standardisé au niveau global.
</p>

<h4>Ne croyez pas (trop) les annonces dans le secteur</h4>
<p>
    Le secteur du numérique et des nouvelles technologies est perpétuellement remué à grands coups d’articles promettant la révolution d’une chose ou de l’autre. De telles affirmations emphatiques font parfois l’objet de rapports pour soutenir ces annonces. Ce mécanisme d'agitation de l’espace médiatique permet d’attirer les capitaux nécessaires à ces entreprises mais n’est pas là pour tracer une quelconque feuille de route ou rendre compte des faits avec précision. Certains technologies sensées révolutionner le monde ne sortiront jamais des laboratoires pour x raisons ou seront utilisés pour un projet beaucoup moins glorieux que celui annoncé. L’intégration concrète de nouvelles technologies numériques semble plutôt regrouper des processus laborieux, lents et bien plus ennuyeux qu’on l’imagine. <b>Bref, si l’entreprise multinationale X affirme qu’elle va révolutionner le secteur ou le service Y grâce à la technologie Z dans N années, il y a de fortes chances qu’elle cherche juste plus de capitaux pour se financer ou à créer un marché</b>.
</p>

<h4>Soyez attentifs aux régimes de visibilité et d’opacité dans le secteur</h4>
<p>
    Tous les spécialistes le répètent à chaque fois, le secteur est très opaque. Il est dur d’obtenir des informations pertinentes et des données utilisables pour la recherche. <b>Un jeu de clair-obscur est observable entre les informations et données qui sont mises en visibilité à outrance et celles qui sont mises en opacité. Des données qui étaient auparavant opaques deviennent visibles, d’autres repartent dans l’ombre, certaines sont rendues très visibles afin d’en obscurcir d’autres</b>. Il faut bien comprendre que dans ce contexte la visibilité est aussi une méthode d’opacification. À l’invitation d’un <a href="https://cemti.univ-paris8.fr/?se%CC%81minaire-doctoral-le-visible-et-l-invisible-sur-les-plateformes" rel="noopener noreferrer" target="_blank">séminaire doctoral au CEMTI (Paris 8)</a> j’ai tenté une première description de ces régimes.
</p>

<figure class="img-figure-large"><div class="img-wrapper" style="padding-bottom: 65%"><img alt="" class="img" loading="lazy" srcset="https://gauthierroussilhe.com/img/blog-paradoxes-01.svg"></div><figcaption>Diapositive issue d'une intervention au CEMTI Paris 8, à gauche les élements mis en opacité, à droite les éléments mis en visibilité (Crédit : Gauthier Roussilhe)</figcaption></figure>

<p>
    L’explication de ce graphique a été l’objet d’une conférence entière donc je ne me permettrai pas de tout reprendre ici sous peine de vous noyer sous l’écrit. Néanmoins, je peux expliquer quelques rouages. En première ligne, j’ai tenté d’expliquer comment la sur-visibilisation sur la consommation d’électricité et les émissions de carbone permettre d’opacifier les discours sur l’ensemble de l’empreinte environnementale (fabrication / usage / fin de vie ; consommation de ressources / d’eau / d’énergie primaire / émissions de gaz à effet de serre). Une partie de cette explication peut être lue dans mon article suivant <a href="territoires-centres-de-donnees.html" rel="noopener noreferrer" target="_blank">sur les centres de données</a>. Avec le recul, il me semble que ces régimes de visibilité et d’opacité s’organisent dans un arsenal de textes publics : les normes, les conférences, les prises de paroles, les comités d’experts, … Il faut donc apprendre à étudier le secteur numérique en négatif, c'est-à-dire s'intéresser bien plus à l'obscurité (ce qui est opaque et ce qui opacifie) qu'à la lumière, sous peine d’amplifier des raisonnements insoutenables à terme.
</p>

<h4>Etudiez les goulots d’étranglements</h4>
<p>
    Le secteur numérique étant à la fois concentré et dilué il est très facile de s’éparpiller et de perdre du temps et de l’énergie dans un sujet dans lequel peu de données sont disponibles et peu de recherche de terrain a été accomplie. Mon conseil est de privilégier les goulots d’étranglement du secteur numérique. <b>Ces goulots désignent pour moi des zones géographiques ou des structures matérielles où se resserrent les différents flux du secteur (matières, ressources, production, capitaux, etc.)</b>. C’est à ce titre que j’ai commencé à étudier <a href="https://gauthierroussilhe.com/post/chip-water-taiwan.html" rel="noopener noreferrer" target="_blank">les industries de fabrications de circuits intégrés à Taïwan</a>. 60% des livraisons mondiales de circuits intégrés proviennent de l’île et ces composants (semi-conducteurs inclus) sont un des éléments fondateurs de la numérisation. Sur un espace géographiquement restreint où passe une telle quantité de flux, les conditions matérielles de production et les impacts écologiques et sociaux sont bien plus visibles et le travail de recherche semble plus “facile”. À voir si cette approche est fertile ou nécessaire sur le long terme.
</p>

<h3 id="prospective">Intuitions</h3>
<p>
    Ces quelques années d’expérience ne m’ont sûrement pas permis de bien comprendre comment les enjeux environnementaux du secteur numérique vont évoluer. Quelques observations et idées se sont toutefois cristallisées jusqu’à formuler quelques intuitions que je partage ici. J'espère bien évidemment que l'avenir ne me donnera pas raison.
</p>

<h4>L’eau sera plus problématique qu’on l’imagine</h4>
<p>
    L’hyper-focalisation sur le carbone et l’électricité cache efficacement les autres grands problèmes environnementaux. De tous ces problèmes, il me semble que <b>la consommation d’eau du numérique peut devenir très problématique dans un futur proche et dans des zones très concentrés</b> : les lieux d’extraction minière (approvisionnement en eau pour le nettoyage et la purification du minerai) ; la fabrication de circuits intégrés (eau ultra-pure, rinçage des wafers, etc.) ; le refroidissement des centres de données en zones désertiques (par évaporation d’eau) ; et la pollution des eaux (rejets miniers et industriels, décharges, etc.).
</p>

<h4>Numérique vs Agriculture</h4>
<p>
    Les besoins en eau de certains acteurs du numérique pourraient se confronter avec le plus consommateur d’eau sur le globe : le secteur agricole. Plus précisément, <b>certains acteurs du numérique pourraient rentrer en concurrence avec les acteurs agricoles pour pomper les eaux souterraines en zones de stress hydrique et pour la captation des eaux de surface (réservoirs, etc.)</b>. Par exemple, en avril 2021, le gouvernement taïwanais a demandé l’arrêt subventionné de l’irrigation de 74 000 hectares de terres agricoles pour maintenir l’approvisionnement en eau d’usines de semi-conducteurs dans le nord de l’île. De plus, les rejets industriels d’usines de fabrication pourraient contaminer plus gravement des rivières et flux qui servent aux activités agricoles. Là encore le cas de Taïwan est intéressant et a été exploré par <a href="https://www.researchgate.net/publication/233466446_The_Dark_Side_of_Silicon_Island_High-Tech_Pollution_and_the_Environmental_Movement_in_Taiwan" rel="noopener noreferrer" target="_blank">Hua-Mei Chiu</a>. De façon générale les activités industrielles, tous secteurs confondus (alimentaire, chimie, métallurgie, etc.) ont presque toujours créé ce genre de situations donc il n’y aurait rien d’étonnant à ce que le phénomène se répète. Malheureusement, il sera bien difficile à des petits fermes et exploitations agricoles de se battre contre des géants du numérique sur l’accès à l’eau. Au niveau global, le fait que Huawei s’intéresse aujourd’hui de plus en plus au secteur agricole et aux <i>Smart Farming Technologies</i> (SFT) n’est pas anodin. Cela permettra d’arbitrer à terme en interne les usages concurrentiels tout en s’assurant l’obtention des capacités productives agricoles, un champ dans lequel les grands acteurs du numérique se sont rarement aventurés mais qui va se révéler de plus ou plus décisif dans les années à venir. 
</p>

<!--           <h4>Futurs sans matérialité</h4>
<p>
    Au fur et à mesure que les questions environnementales vont devenir pressantes et être visibles dans des territoires bien définis, les grands acteurs du numérique vont diluer ces problèmes dans une "matérialité de façade". <b>Nous aurons de plus en plus de rapports RSE aux résultats emphatiques mais avec des données agrégées et invérifiables, et cela au fur et à mesure que ces acteurs garantissent leurs propres conditions matérielles (poste source d'électricité privé, station de pompage privé, etc.)</b>. La matérialité communiquée sera focalisée sur des facteurs environnementaux qui peuvent être comptablement maitrisables (électricité, "neutralité carbone") et opacifiera le reste des grands facteurs environnementaux. Nous aurons face à nous de plus en plus de promesses de futurs numériques soutenables (non vérifiées et vérifiables) où les conditions matérielles sont de plus en plus opacifiées et montrées au compte-goutte dans une sorte de <i>Sustainability-as-Usual</i>.
</p>
-->
<h3 id="mettrefin">Mettre fin au régime d'exception</h3>
<p>
    Le présent exposé permet d’actualiser l’objectif à moyen et long terme des acteurs qui travaillent sur la question environnementale du numérique et au-delà. <b>La question stratégique aujourd’hui me semble être la suivante : comment mettre fin au régime d’exception du secteur numérique ?</b> Tout ce que j’ai décrit plus haut n’est finalement que quelques pièces du puzzle qui décrivent ce régime. Cet exceptionnalisme empêche aujourd’hui de contester l’axe de développement du secteur numérique et ralentit considérablement la prise en compte sérieuse des enjeux environnementaux de celui-ci. Pourtant, en regardant de près l’histoire des techniques à partir du XVIIIème siècle et l’histoire du développement industriel, le secteur numérique apparaît tout à fait traditionnel. Il transforme, certes, plus ou moins rapidement les modes de vie de nombreuses sociétés sur Terre mais ses conditions matérielles de déploiement et de production sont semblables à bien d’autres industries d’avant qui, elles, ont été régulées. 
</p>  

<p>
    Le secteur entretient son exceptionnalisme en maintenant un effet d’annonces permanent : telle application technologique numérisée va révolutionner telle ou telle chose. Cet effet est aussi nécessaire pour maintenir les flux de capitaux nécessaires au développement du secteur. De même, le secteur s’est associé aux discours qui associent progrès technologique au progrès social, transformant symboliquement, par un sophisme bien connu, toute contestation envers le secteur numérique en une volonté de régression sociale. Les promesses d’emplois et de retombées économiques permettent aussi d’accéder à de nombreuses facilités au niveau local. Je décris plus en détail certains facteurs qui rendent le débat laborieux dans <a href="limites-debat.html" rel="noopener noreferrer" target="_blank">l’article suivant</a>. En conclusion, je pense que mon travail de matérialisation et de territorialisation du secteur numérique vise très modestement à participer à un effort de “dé-exceptionnalisation” afin de faire rentrer le processus de numérisation en débat.
</p>

