title: Some thoughts on how to make a book, three months after I made one
url: https://www.baldurbjarnason.com/2023/how-i-made-my-book/
hash_url: 8cb87dbe21c3f5a7a69735a70daf51c3

<p>Writing a book is both very complicated and extremely simple.</p>
<p>It’s simple: you only need to have something to say, and then you say it until you’ve made your point.</p>
<p>How you do any of those things is fractally complicated—a divergent problem, in <a href="https://en.wikipedia.org/wiki/A_Guide_for_the_Perplexed#Two_types_of_problems">E. F. Schumacher’s framing</a>, that gets more and more complicated the closer you look. Even finding out what you have to say can be a bit involved.</p>
<p>Thankfully, there is an endless selection of books to help you with the task.</p>
<p>Some of my favourites:</p>

<p>There are a lot of them out there. Most of them are good, which is unsurprising since they are written by accomplished writers.</p>
<p>I’m not in that category, so I’m not the person you should look to for writing advice, but I know a thing or two about what happens <em>after</em> you’ve written that book. Now, if you are planning to get a publisher for it, their job is to hire people who know what they’re doing to do this for you.</p>
<p>But what if you’re self-publishing? What if you’re self-publishing and selling directly from your own website? What if you are writing on a topic like software development or business-oriented analysis that trade publishing does not care about?</p>
<p>What happens when you have to do it yourself?</p>
<p>That’s something I can help you with, having both worked in publishing for several years and having put together <a href="https://www.vonbedon.is/">several</a> <a href="http://thisisnotabook.baldurbjarnason.com/">book-like</a> <a href="https://softwarecrisis.baldurbjarnason.com/">objects</a> in collaboration with others.</p>
<p>What follows are some thoughts on how I made my book, <a href="https://softwarecrisis.baldurbjarnason.com/">Out of the Software Crisis</a>, collected mostly for my own records, but hopefully useful to the rest of you.</p>
<h2 id="dont-copy-what-the-trade-publishing-industry-says-it-does">Don’t copy what the trade publishing industry says it does</h2>
<p>Don’t trust what people in publishing say about the publishing process.</p>
<p>They aren’t lying, per se, but a lot of what they say is based on how publishing works in its less dysfunctional pockets, which are getting rarer and rarer. Publishing isn’t what it used to be.</p>
<p>‘Quality’, for lack of a better word, has deteriorated for large parts of the trade publishing industry. Print and typesetting quality has declined for many titles that have been switched to Print-On-Demand. Publishers keep cutting back on their investment in editing. They are exceptionally bad at marketing and actually <em>selling</em> their wares.</p>
<p>Many commentators who are fond of talking about how many services you are missing out on if you self-publish are just plain unaware of how little most modern trade publishing cares about your average first-time author, or how much the industry’s overall quality control has declined over the past couple of decades.</p>
<p>Publishing, as a whole, also doesn’t understand economics.</p>
<p>This is a near-universal constant in English-language trade publishing. I’ve long since lost count of how many times an editor or manager at a publisher bragged to me (literally <em>bragged</em>) about not understanding mathematics or having never read an ebook. And you can tell from the outcomes. Publishers regularly overspend on titles that never had any hope of recouping the investment and underspend on titles that clearly could have done much better with minimal investment. They’re shit with money and survive because the few blockbusters they pick by accident are <em>exceptionally</em> profitable. That renders quite a bit of their advice unusable to anybody who’s averse to losing money.</p>
<p>There are publishers out there who are good at what they do. And there are teams within bad publishers who are also good at what they do. If you ever get a chance to work with one of them, grab it, but be aware that they are the exception, not the rule. They will also constantly be struggling against upper-level mismanagement and fighting to protect you from the background radiation of plutonium-level executive assholery—of which publishing has in abundance. Sometimes they succeed. Sometimes they don’t.</p>
<p>What people pushing publishing services say publishers do generally isn’t what trade publishers actually do. Not anymore.</p>
<h2 id="keep-your-budget-proportional-to-your-expected-audience-and-return">Keep your budget proportional to your expected audience and return</h2>
<p>If your ebook is an extended white paper analysing the specific business return of a narrow piece of technology, you shouldn’t go off and spend $2000 on structural and line editing. And you definitely should not go and commission a cover design for $500.</p>
<p>You need to be aware of what your target audience considers to be ‘quality’. Trade publishers never (or rarely) do this assessment, but it can shave thousands off your budget if you do it thoughtfully.</p>
<p>For example, software developers might forgive awkward grammar and weird sentence structure but will get ticked off by a spelling error or technical mistake.</p>
<p>Business readers have a high tolerance for <em>exceedingly</em> bad writing—prose so awful that it boggles the mind—as long as the text has the correct tone and the numbers and analysis add up.</p>
<p>These are generalisations. You should know your audience well enough to put together a ‘persona’ of sorts—ideally, one backed by a bit of research—that can help guide you through the book production process.</p>
<p>Since <a href="https://softwarecrisis.baldurbjarnason.com/"><em>Out of the Software Crisis</em></a> is targeted at software developers, I decided not to invest in a freelance editor but instead focus on getting as many expert advance readers as I could.</p>
<p>In other words, I decided to leverage the <em>wisdom of crowds</em>.</p>
<h2 id="_the-wisdom-of-crowds_-actually-works"><em>The Wisdom of Crowds</em> actually works</h2>
<p>For a short period of time during Web 2.0, <em>crowdsourcing</em> or <a href="https://en.wikipedia.org/wiki/The_Wisdom_of_Crowds"><em>The Wisdom of Crowds</em></a> was supposed to be the next big thing. Poorly implemented and misunderstood, the tech industry did its usual thing of poisoning the well on a fundamentally sound idea for at least a couple of decades. (See also: the use of game design ideas in UX, Merkle trees, textures inspired by real-world objects in UI design, peer-to-peer networking, and, well, ebooks.)</p>
<p>This fad resulted in overhyped mistakes like Iceland’s aborted and unsuccessful “crowdsourced” constitution.</p>
<p>What the tech industry did, in its usual form, is completely disregard facts, science, and existing research while shipping something based on a complete misreading of the core idea.</p>
<p>In the case of <em>The Wisdom of Crowds</em>, the book has a simple thesis backed by quite a bit of research.</p>
<p>If you have a group of people with:</p>
<ol>
<li>A diversity of opinion. (But they don’t have to be qualified or be experts.)</li>
<li>Who can give you that opinion or feedback independently from each other. (That is, they don’t see <em>anything</em> from each other and <strong><em>absolutely</em></strong> should not communicate with each other.)</li>
<li>They have diverse specialities.</li>
<li>You can collect their feedback and opinions into a collective decision.</li>
<li>You trust the group overall.</li>
</ol>
<p>Then the quality of the collective decision has a decent chance of rivalling that of an expert.</p>
<p>There are plenty of situations where this dynamic breaks down, but if you’re a self-publisher it has a corollary that is particularly useful:</p>
<p>A dozen readers who:</p>
<ol>
<li>You trust.</li>
<li>Are willing to invest the time and energy to give detailed feedback on your book.</li>
<li>Have diverse experiences and specialities.</li>
<li>And won’t talk to each other about the book.</li>
</ol>
<p>Will collectively give you surprisingly good editorial feedback.</p>
<p>Even a group of beta readers as small as five or six will give you insight into what works and doesn’t. Even disregarding the “crowd” aspect, the old free software adage <a href="https://en.wikipedia.org/wiki/Linus%27s_law">“given enough eyeballs, all bugs are shallow”</a> probably applies <em>more</em> to prose than to software, because you don’t need to know anything about coding to spot a spelling error or indecipherable sentence.</p>
<p>Get as many advance readers as you can.</p>
<h2 id="self-editing-can-get-you-part-of-the-rest-of-the-way">Self-editing can get you part of the rest of the way</h2>
<p>It isn’t perfect and isn’t as good as a professional editor, but it can go a long way. Books like <a href="https://www.goodreads.com/book/show/580473.Line_by_Line">Line by Line</a> and <a href="https://www.amazon.com/Artful-Edit-Practice-Editing-Yourself/dp/0393332179">The Artful Edit</a> will help you make the most of your resources by helping you edit yourself.</p>
<p>Sleeping on it—that is, letting your mind lose some of its familiarity with the text through the passage of time—also helps. Letting a manuscript sit for a few days before rereading it will help you see it as if it had been written by somebody else.</p>
<p>Tools like <a href="https://grammarly.com/">Grammarly</a> and <a href="https://prowritingaid.com/">ProWritingAid</a> help too. They aren’t perfect. Grammarly will occasionally give advice that is flat-out incorrect, so accepting all of its suggestions is likely to <em>introduce</em> new errors in your text. This is not ideal but is a common flaw in software that uses AI and machine learning to the extent that Grammarly does. I haven’t tested ProWritingAid myself, so I don’t know if it suffers from this issue as well.</p>

<p>If you don’t know Indesign, don’t use Indesign. If you don’t know CSS, don’t use a CSS-based tool to generate the CSS. If you don’t know LateX, don’t use LateX. If you don’t know Markdown, don’t use Pandoc.</p>
<p>If you don’t know or have a tool or app that generates readable PDFs or EPUBs, you should probably buy or rent one. I hear <a href="https://vellum.pub/">Vellum</a> works well for Mac users, but it’s too expensive for one-time use. Some swear by <a href="https://www.atticus.io/">Atticus</a>, which costs less. They both would have been ‘good enough’ for my purposes, but since I’m comfortable with Markdown, HTML, and CSS, using <a href="https://pandoc.org/">Pandoc</a> made the most sense.</p>
<p>If you’re comfortable with Markdown then Pandoc is <em>amazing</em>. It integrates out of the box with both <a href="https://weasyprint.org/">Weasyprint</a> and <a href="https://pagedjs.org/">paged.js</a>. Either of them is a decent option for generating PDFs. Paged.js uses headless Chrome, which gives it access to a broader spectrum of CSS features and makes it a little bit flakier. For example, I can’t get headless Chrome to hyphenate text on the Windows Subsystem for Linux.</p>
<p>I’ve put together a <a href="https://gist.github.com/baldurbjarnason/31bcd04cc898f42754ea6873aa3a9374">gist with the CSS and script I used to build the book</a>. It probably won’t work for you out of the box, but it should serve as a starting point.</p>
<h2 id="book-covers-are-both-simple-and-tricky">Book covers are both simple and tricky</h2>
<p><em>Books covers are simple:</em></p>
<p>The only purpose of a book’s cover is to sell the book. The less important the cover is to the book purchase decision for your audience, the more generic you can go. The cover I made for <a href="https://softwarecrisis.baldurbjarnason.com/">Out of the Software Crisis</a> is neither great nor bad. It does the job. I doubt that one made with an online tool would have been worse. But I’m also sceptical that a professionally designed one would have sold more copies.</p>
<p>People often forget that modern covers absolutely need to work at thumbnail sizes. That’s how most people will experience it. Subtlety will be lost in a grid of stamp-sized covers on an iPad or your phone.</p>
<p><em>Book covers are tricky:</em></p>
<p>The cover sets the tone for the book, frames it, and defines its boundaries. It needs to tell the reader where the book belongs in the broad genre picture of publishing. A bad book cover will set your readers up to be more critical of it than otherwise.</p>
<p>It is the book’s representative. How much work to invest in a cover is always going to be a judgement call on your part.</p>
<h2 id="spend-a-disproportionate-amount-of-time-on-the-sales-page">Spend a disproportionate amount of time on the sales page</h2>
<p><a href="https://softwarecrisis.baldurbjarnason.com/">The sales page for my book</a> was read, analysed, edited, and torn apart by many more people before publishing than any passage of a similar length in the book itself.</p>
<p>The 30x500 Slack community was invaluable here, but I also reached out to too many friends and relatives to count. That page is the most important in the book, despite not being in the book. Reading a sales page is less of an investment of time than an entire book, so getting people to read through and criticise it was much easier than for the book proper.</p>
<p>If you know people who have experience with writing sales copy, get their feedback.</p>
<p>You want a sales page that will make it crystal clear to the reader what the book is, what value it provides, and whether it will be useful to them. That sells.</p>
<h2 id="do-set-up-a-mailing-list-and-landing-page-for-the-book-launch">Do set up a mailing list and landing page for the book launch</h2>
<p>ConvertKit’s tools worked extremely well. You might find something cheaper, but it probably won’t be any better.</p>
<h2 id="use-a-sales-platform-that-takes-care-of-sales-tax-and-vat-for-you">Use a sales platform that takes care of sales tax and VAT for you</h2>
<p>I tried three different platforms. They all looked good.</p>
<ul>
<li><a href="https://payhip.com/">Payhip</a>. Nice UI. Nice checkout. A lot of features. The downside is that you need either a Stripe account (not available in Iceland) or PayPal (quite shitty in Iceland). An excellent option if you’re US-based.</li>
<li><a href="https://fastspring.com/">Fastspring</a>. Been around forever. Works quite well, but the checkout pages look dated, which is something you can fix.</li>
<li><a href="https://www.lemonsqueezy.com/">Lemon Squeezy</a>. The new kid on the block. Has a really nice design. Some mailing list features are integrated. This is the service I ended up with, mainly because I like its look and feel.</li>
</ul>
<p>I tried to get up and running on Paddle but couldn’t for the life of me get a domain approved.</p>
<h2 id="avoid-selling-on-amazon-if-you-can">Avoid selling on Amazon if you can</h2>
<p>If you’re bringing the audience to the table, selling on Amazon is often a waste of time and money. If you’re selling direct, a service like Lemon Squeezy will charge you 5% + 50¢. Amazon will charge you <strong><em>65%</em></strong>, unless you massively underprice yourself and keep the book price under $10, in which case it’ll still charge you 30%.</p>
<p>There are circumstances where being on Amazon will bring you an audience that makes that discrepancy worthwhile. But, if the audience is discovering the book through your efforts first, not selling via Amazon can triple your revenue.</p>
<p>I did end up selling the book in Amazon’s Kindle store, but only after already establishing direct sales as the primary way for buying the book. It’s only sold a handful of copies so far. I’m not convinced selling there was the right decision.</p>
<h2 id="leverage-the-expectations-of-your-audience-wherever-you-can">Leverage the expectations of your audience wherever you can.</h2>
<p>For example, software developers are more comfortable with the notion of updates and ‘bug’ fixes than many other professions. They are largely appreciative of the “get it out early, fix in updates” approach to both software and books.</p>
<p>They might <em>prefer</em> that everything is perfect out of the box, but updates and corrections are not a dealbreaker.</p>
<h2 id="try-not-to-freak-out">Try not to freak out</h2>
<p>This is a stressful process. There’s a lot that can go wrong. But it’s also quite rewarding.</p>
