title: How Google perfected the web
url: https://www.theverge.com/c/23998379/google-search-seo-algorithm-webpage-optimization
hash_url: 3debc675a055d691b32c7d6904531eb4
archive_date: 2024-01-09

<div class="text-block ">
<p>As the 14th season of Bravo’s <em>Real Housewives of New York City </em>came to a close this fall, I found myself on Reddit, reading rumors about the marriage and divorce timeline of one of the show’s stars. Redditors wanted more clues about a fishy relationship history to see if they could uncover a cheating scandal.</p>

<p><em>Were divorce papers public record in New York?</em> I wondered. I did a quick Google search to find out.</p>

<p>The search results page was filled with my question’s exact words, repeated across site after site — websites for law firms, posts on forums, ads for creepy lookup tools — but the answer to my actual question was harder to find. At the top of the results page on my phone, Google offered two featured snippets of information quoting different websites. The first one: “Divorce records are <strong>not public in New York</strong> due to the sensitive nature of many divorce proceedings.” The second: “Due to the state’s underlying legislation regarding family law cases, <strong>each divorce is a matter of public record.</strong>”</p>

<p>Google bolded both snippets, but it wasn’t clear to me how they squared. I clicked on both.</p>

<p>The two law firm websites were part of an ecosystem I didn’t know existed until I accidentally went looking for it. Law firms across different fields — family law, personal injury, employment lawyers — have blogs full of keyword-addled articles being churned out at a surprisingly fast clip. The goal for firms is simple: be the top result to pop up on Google when someone is looking for legal help. The searcher might just end up hiring them.</p>

<p>Many of these blog posts are written by people like E., a self-employed content writer who juggles law firm clients that want Google-friendly content. E. does not have a legal background; they’re just a competent writer who can turn in clean copy. They trawl health department records, looking for nursing homes that get citations for neglect or other infractions. Then E. writes a blog post about it for a firm, making sure to include the name of the offender and the wrongdoing — keywords for which concerned patients or families will likely be searching. (E. requested anonymity so as to not jeopardize their employment.)</p>


<p>“My bosses, they all don’t want anyone else to know that they use me or that we have the specific process that we have,” E. says. Their name is nowhere to be found, but their writing is often the first thing a searcher will see. The pages were made to be found by people like me.</p>

<p>Google controls around <a href="https://www.similarweb.com/engines/united-states/">90 percent of the search market</a>, by some measures, so it’s too valuable a referral source to just leave up to luck. Search engine optimization — or SEO, the practice of tweaking content and websites to get Google to boost your visibility — is everywhere, including on the page you’re reading now. And once you see it or SEO-ify your own work, like E. has, it’s impossible not to notice.</p>

<p>Google’s outsized influence on how we find things <a href="https://www.theverge.com/23712602/google-search-25-years-anniversary-ai-artificial-intelligence">has been 25 years in the making</a>, and the people running businesses online have tried countless methods of getting Google to surface their content. Some business owners use generative AI to <a href="https://www.theverge.com/23753963/google-seo-shopify-small-business-ai">make Google-optimized blog posts</a> so they can turn around and sell tchotchkes; brick-and-mortar businesses are <a href="https://www.theverge.com/2023/10/26/23931825/google-search-local-seo-thai-food-near-me-maps">picking funny names like “Thai Food Near Me”</a> to try to game Google’s local search algorithm. <a href="https://www.theverge.com/features/23931789/seo-search-engine-optimization-experts-google-results">An entire SEO industry</a> has sprung up, dedicated to trying to understand (or outsmart) Google Search. </p>

<p>The relentless optimizing of pages, words, paragraphs, photos, and hundreds of other variables has led to a wasteland of capital-C Content that is competing for increasingly dwindling Google Search real estate as generative AI rears its head. You’ve seen it before: the awkward subheadings and text that repeats the same phrases a dozen times, the articles that say nothing but which are sprayed with links that in turn direct you to other meaningless pages. Much of the information we find on the web — and much of what’s produced for the web in the first place — is designed to get Google’s attention.</p>

<p>We often hear about the latest engagement hacks on other platforms like Instagram, TikTok, or X, formerly known as Twitter. But Google is consequential above all of these, acting essentially as the referee of the web. Yet deep knowledge of how its systems work is largely limited to industry publications and marketing firms — as users, we don’t get an explanation of why sites suddenly look different or how Google ranks one website above another. It just happens.</p>

<p>Bit by bit, the internet has been remade in Google’s image. And it’s humans — not machines — who have to deal with the consequences.</p>

</div>



<div class="text-block ">
<h2>1. Site performance and accessibility</h2>
<p>There’s an inherent contradiction in what Google promises is the best way to succeed on Search. Publicly, Google representatives like search liaison Danny Sullivan give a simple, almost quaint answer to business owners who want help: you just need to make great content for people, not Google’s robots.</p>

<p>At the same time, Google’s “<a href="https://developers.google.com/search/docs/fundamentals/seo-starter-guide">SEO Starter Guide</a>” is nearly 9,000 words long with dozens of links to additional material. There are several SEO industry publications, plus an untold number of scrappy blogs, marketing firms, and self-proclaimed SEO gurus promising to demystify Google’s black box algorithm. Small business owners must either learn how to do SEO or hire someone — even multiple people or special firms — to do it for them. It’s expensive, time consuming, and often confusing work, and failure to learn the ropes could mean trouble if your traffic begins to tank unexpectedly. Google executives like Sullivan often respond to the folk wisdom of the SEO industry with a six-word incantation meant to absolve them of the industry’s worst practices: <em>that’s not what the guidelines say</em>. It can feel like the guidelines are there to protect Google’s reputation, not actually help anyone get search traffic.</p>

<p>Optimizing pages for Google isn’t inherently a bad thing. Google uses its influence over the web to push for objectively good results, <a href="https://www.searchenginejournal.com/ranking-factors/page-speed/">like fast-loading sites</a> and accessibility features like alt text on images, which can help audiences understand what’s on a page if an image doesn’t load or if readers use assistive technology like screen readers. Google’s <a href="https://web.dev/articles/vitals#core-web-vitals">Core Web Vitals</a> metric pushes down sites with certain kinds of intrusive ads or which have slow-loading ads that cause content on the page to shift around.</p>

<p class="pullquote"></p><q>“[Google’s changes] did sort of homogenize the design of the internet.”</q><p>Perhaps Google’s most benevolent push has been toward a fast, mobile-first web that has forced small and large publishers alike to overhaul their publishing platforms. But even that effort has come with collateral damage — see the entire news industry reluctantly <a href="https://www.theverge.com/23711172/google-amp-accelerated-mobile-pages-search-publishers-lawsuit">embracing Google’s AMP format</a> — or in the case of smaller blogs, a flattening and whitewashing of web design across the board.
</p><p>Valerie Stimac Bailey, a professional blogger of a decade, remembers in 2021 when Google began using a <a href="https://developers.google.com/search/blog/2021/04/more-details-page-experience">new metric</a> to rank sites, called “page experience,” that emphasized giving readers a “<a href="https://developers.google.com/search/blog/2020/05/evaluating-page-experience#about-page-experience">delightful</a>” web to browse. Passing Google’s Core Web Vitals tests became all the more important — Google would look at load times, interactivity, and whether visual elements would move around unexpectedly. </p>

<p>Bloggers like Stimac Bailey, along with an untold number of other site operators and web companies, saw the writing on the wall: Google might not like your old site, with its giant logos and custom fonts, or the ads that cause text to jump around. Companies like Mediavine, a popular ad-management company, <a href="https://www.mediavine.com/newsroom/mediavine-rolls-out-wordpress-theme-framework-to-the-open-web-empowering-independent-publishers-to-pass-googles-core-web-vitals/">released web design frameworks</a> optimized for this new Google metric and Stimac Bailey, like many others, switched and redesigned her site. But she found the new theme “sterile,” she tells me, and it lacked customization options. It didn’t feel like part of her brand.</p>

<p>“I get that that probably was the impetus for a lot of people with really old, slow themes that were not handling mobile well to move to something that was faster for the world of the mobile-first indexing and internet,” Stimac Bailey says. “That was a good impact… but simultaneously, it did sort of homogenize the design of the internet.”</p>

<p>Stimac Bailey, who in the past published up to 11 blogs at a time, has experimented with different website themes. All eight of her current sites look nearly identical — her <a href="https://www.valisemag.com/">Alaska travel blog <em>Valerie &amp; Valise</em></a> looks the same as <em>Site School</em>, a blog where she <a href="https://siteschool.co/q3-2023-check-in/#Eat_Like_Bourdain">shares data-heavy analyses</a> of how her portfolio of websites is performing. </p>

<p>“People spent a lot of money, and a lot of time, and a lot of heartache and stress and psychology redesigning websites,” Stimac Bailey says.</p>

<p>Taking Google’s advice on creating good, fast, accessible websites sounds nice in theory; why not do what the search engine prefers and help your readers in the process? Creators I spoke to acknowledged that changes sometimes benefit Google and readers alike. But the line between what’s good for the search algorithm and what’s good for audiences has become blurry over time, and in some cases, the two are treated essentially as the same thing.</p>

</div>



<div class="text-block ">
<h2>2. Page design and structure of articles</h2>
<p>The small, behind-the-scenes changes site operators deployed over the years have made browsing the web — especially on mobile — more frictionless and enjoyable. But Google’s preferences and systems don’t just guide how sites run: Search has also influenced how information looks and how audiences experience the internet. The project of optimizing your digital existence for Google doesn’t stop at page design. The content has to conform, too.</p>

<p>Take, for example, the question-based subheadings that are rampant on pages ranging from <a href="https://www.sofi.com/learn/content/what-is-an-ira/">personal finance explainers</a> to <a href="https://thepointsguy.com/guide/best-time-to-book-a-flight/">travel tips</a> to <a href="https://www.thepioneerwoman.com/home-lifestyle/a41502817/when-is-daylight-saving-time/">annual event reminders</a>. Sections like “When should I make IRA contributions?” or “What states are getting rid of Daylight Savings time?” will cascade down a page, presumably to help a reader scan for information. But subheadings are also a piece of information Google uses to understand what a page is about and to rank it in Search. Historically, subheadings <a href="https://www.searchenginejournal.com/ranking-factors/html-heading-tags-h2-h6/">have been an easy, fast way</a> to juice content for maximum visibility.</p>

<p>Some bloggers and outlets scrape the “People Also Ask” panel on search results pages for ideas: the Google-curated section spits out strangely worded or oddly specific questions like, “What is the healthiest vegetable 2023?” and “What two vegetables can be eaten raw?”</p>

<p>Sean Bromilow, a food writer based in Canada, has reformatted his blog posts in hopes that Google will pick up his content for placement in these fields. On a page for cucamelons, he added an FAQ section featuring questions like, “How do you eat cucamelons?” and “Are cucamelons a GMO?”</p>

<p>“I did that in direct response to Google’s [People Also Ask questions] that they introduced,” he says. </p>

<p class="pullquote"></p><q>Some creators scrape the “People Also Ask” panel for story ideas</q><p>A Q&amp;A format might often be the most effective way to write a story or share information — I’ve <a href="https://www.theverge.com/23802895/sag-aftra-writers-guild-strikes-hollywood-influencer-rules">done stories in this format</a>, too. But other times, question-based subheadings are harder to read, repeating the same phrases without adding anything substantial. Browse <a href="https://sublimelife.in/blogs/sublime-stories/gua-sha-101-everything-you-need-to-know-about-how-to-use-a-gua-sha">this article about gua sha</a>, a massaging technique with roots in traditional Chinese medicine, and you’ll find headings including, “What is a gua sha,” “What are the benefits of a gua sha,” “How to find your gua sha,” and “How to use your gua sha.”
</p><p>A table of contents, too, has become a common sight, appearing at the top of articles. On a post about <a href="https://www.valisemag.com/alaska-big-five/">animals to look out for in Alaska</a>, for example, Stimac Bailey has 10 sections in the table of contents, each linking to the corresponding part of the blog post. Having a linked table of contents allows readers to skip to the part they most want to read, like if someone is strictly interested in seeing caribou.</p>

<p>But the table of contents sections also work as jump links on Google Search that appear below the headline and other metadata. Stimac Bailey gets a reasonable amount of traffic to her <a href="https://www.valisemag.com/pacific-coast-highway-guide/">Pacific Coast Highway guide</a>, not from searchers clicking the title but through people clicking on one of the jump links below. Some SEO strategists even debate whether bloggers should leave their table of contents expanded or collapsed for maximum SEO juice. Stimac Bailey keeps hers collapsed but recently heard from a person selling SEO services that your table of contents should be auto-expanded.</p>

<p>“At a certain point, I don’t care if it costs me time on site or it costs me ad views or costs me bounce rate or whatever it might be,” she says. “I like my site to look the way I want it to look, so that’s what I’m going to do.”</p>

<p>But many websites just do what they think Google wants or what’s being recommended by SEO experts, even if there’s no guarantee it will work. Google is both overbearing with manuals and withholding of clear answers. Give too much away, and everyone could game the system. In that void, creators and website operators throw things at the wall to see what sticks. And once they start designing their page for Google, it’s easy for their content to be fashioned for Google, too.</p>

</div>



<div class="text-block ">
<h2>3. Keyword research and what content is made</h2>
<p>For publishers handcuffed to Google Search traffic, there’s often no reason to produce content if people aren’t searching for it. So marketers, writers, and bloggers use a suite of keyword research tools to assess whether there’s enough interest to write the article or make the video in the first place. The result is that publishers end up producing a mountain of material, with Google keywords essentially acting like the assigning editor.</p>

<p>When Stimac Bailey writes for her <a href="https://londonmymind.com/">London travel blog</a>, for example, she strategically picks topics that the site will be able to rank highly for — keywords and topics that are too competitive get put on the backburner.</p>

<p>“[My writers and I] work on picking topics together, but we need them to be productive because not only am I [monetizing them], I’m paying people for their work, and I’m trying to pay very fairly for that work,” she says. “It’s like, ‘I gotta find these low-competition, high-volume, magic keywords.” For a popular destination like London, those magic keywords don’t really exist.</p>

<p>Catherine Cusick understands this tension well. Cusick worked in media for years — including in SEO — before creating the <a href="https://www.selfemployedfaq.com/">Self-Employed FAQ</a> in March. The subscription-driven business acts as a help guide for people who are new to self-employment or who simply have a specific question they can’t get an answer to elsewhere. </p>

<p>Most of Cusick’s answers to queries like “Do I need an accountant?” or “What are my healthcare options?” are behind a paywall, so she curates a small number of unlocked articles meant to give prospective customers a sampling of what she offers. These are what Cusick calls “SEO plays.”</p>


<p>For these articles, she is <a href="https://www.selfemployedfaq.com/how-to-pay-yourself-single-member-llc">only targeting long-tail keywords</a> — lengthier search terms that are often more specific and, as a result, have fewer people searching for them and are less competitive.</p>

<p>“The keyword search term that I am going for is, ‘How to pay yourself from a single member LLC.’ My game is entirely long-tail keywords,” she says. “I’m not even competing with ‘How to pay myself LLC.’ Like, that’s too high of a term for me, let alone something like ‘LLC.’”</p>

<p>Cusick wrestles with the disconnect between who her business is for — scared, uncertain people trying to make a living — and the SEO requirements she needs to fulfill. Time strategizing and reading technical manuals can feel like time “stolen” from making in-person connections and writing paywalled articles meant to help people through self-employment.</p>

<p>“I will need to have a different page for humans, and then another page that’s more of a directory that points humans who’ve arrived to the directory to other pages that will tell them a story,” she says. “The directory page can be structured in a way that makes search engine crawlers satisfied.” In Cusick’s view, we’re asking one piece of content to do too much: fulfill all the SEO requirements <em>and </em>do<em> </em>the careful, uninterrupted work of getting real answers to a reader.</p>

<p class="pullquote"></p><q>I rewrote my prose over and over, but it didn’t seem to satisfy my robot grader</q><p>In an emailed statement, Google spokesperson Jennifer Kutz offered a dozen links to public documentation around search, along with generalities about keeping content “helpful” and “relevant.” All points underscored the company’s most common refrain: make content for human audiences.
</p><p>“We’ve given longstanding guidance to create content that’s first and foremost helpful, and we work very hard to ensure that our ranking systems reward content designed for people first. Many sites perform well on Search simply by creating this helpful content, without undertaking extensive SEO efforts,” Kutz tells <em>The Verge</em>. “We continuously refine our ranking systems, and where we identify areas we can improve in ranking people-first content, we prioritize them. For more than a year, we’ve had focused efforts to <a href="https://blog.google/products/search/google-search-discussions-forums-news/">show</a> more <a href="https://blog.google/products/search/google-search-perspectives/">content</a> based on first-hand <a href="https://blog.google/products/search/google-search-november-2023-update/">experience</a> in Search, and to <a href="https://blog.google/products/search/more-content-by-people-for-people-in-search/">reduce</a> content created solely for search engines, and this work continues.”</p>

<p>Kutz did not comment on my questions around specific strategies outlined in this piece, saying that giving granular guidance might make creators “lose sight” of the people-first guidance put forth by Google. Instead, the advice is for website operators to “ask themselves if [a tactic] would be helpful for someone visiting their site.”</p>

<p>But in order to be helpful to readers, website operators need people to visit their site in the first place. Fine-tuning content to match exact search terms is a common strategy that can entice users to click on a page that looks like it will answer their question. That doesn’t guarantee content will be better or even good — and sometimes, how users search can create an echo chamber of errors, oft-repeated misinformation, or poorly researched content.</p>

<p>One instance of errors multiplying sticks out to Bromilow, the food writer. For a while, he says that Google was returning a litany of incorrect information about Ethiopian cardamom, or korarima. Though black cardamom and korarima look similar, their flavors are not. Websites and writers — and by extension, Google results — were confusing the ingredients. At one point, Bromilow says the first picture on Google Images was of the wrong plant. </p>


<p>“If people are searching the wrong thing because that’s what they’ve been given, how do you return a result to them that explains that they’re incorrect, while also being found by them?” Bromilow says. “You don’t want to reinforce the mistake, right? It’s really weird and complicated.”</p>

<p>That Ethiopian recipes are being translated from Amharic to English also brings a host of problems: how should Bromilow spell the names of dishes? Should he use whatever spelling people are searching for the most? <a href="https://www.diversivore.com/savory-pancakes-with-four-variations/">A post on savory pancakes</a> sums it up, in which the Canadian Bromilow explains why he’s opted to omit the “u” in savoury: “The choice, while it breaks my maple-syrup filled heart, is obvious — savory is searched for more often, and using that spelling is more likely to [get] a recipe noticed by the all-powerful and oft-mysterious search engine algorithms.”</p>

<p>To understand what pure SEO-optimized writing looks like, I put <a href="https://www.theverge.com/2023/10/26/23931825/google-search-local-seo-thai-food-near-me-maps">my recent story about Google-optimized local businesses</a> through an SEO tool called Semrush that’s reportedly used by 10 million people. </p>

<p>Among its suggestions: write a longer headline; split a six-sentence paragraph up because it’s “too long”; and replace “too complex” words like “invariably,” “notoriety,” and “modification.” Dozens of sentences were flagged as being confusing (I disagree) — and it really hated em dashes. I rewrote my prose over and over, but it didn’t seem to satisfy my robot grader. I finally chose one thought per sentence, broke up paragraphs, and replaced words with suggested keywords to get rid of the red dots signaling problems. </p>

<p>The result feels like an AI summary of my story — at any moment, a paragraph could start with “In conclusion…” or “The next thing to consider is…” The nuance, voice, and unexpected twists and turns have been snuffed out. I’m sure some people would prefer this uncomplicated, beat-by-beat version of the story, but it’s gone from being a story written by a real person to a clinical, stiff series of sentences.</p>

<p>Now imagine thousands of website operators all using this same plug-in to rewrite content. No wonder people feel like the answers are increasingly robotic and say nothing.</p>

</div>



<div class="text-block ">
<h2>4.  Building “trust,” Google’s way</h2>
<p>If you’re a regular reader of <em>The Verge</em>, you might have noticed some changes to our author bylines in recent months: they’re a lot longer, with more details, name-dropping, and quantifying our professional experiences. You can thank Google for that.</p>

<p>In December 2022, Google updated the metrics it uses to assess the quality of the content it serves up to searchers. Previously, the company looked for expertise, authority, and trust in webpages — <a href="https://developers.google.com/search/blog/2022/12/google-raters-guidelines-e-e-a-t">now, the company said it would tack on <em>experience</em></a> to the rating system. In SEO parlance, it’s called E-E-A-T. </p>

<p>Demonstrating<em> </em>experience by Google’s standards is supposed to show audiences that the person producing the content has participated in the topic matter in some way. If they’re writing about hairdryers, one way to show experience might be a reviewer mentioning how they’ve tested different products themselves. If someone is recommending a restaurant, they could indicate they dined there. The emphasis on experience and trust is in response to issues that, in some ways, are Google’s own creation — on Search, <a href="https://www.propublica.org/article/google-alphabet-ads-fund-disinformation-covid-elections">anyone can profit from clicks</a>, including websites spewing disinformation.  </p>

<p>It’s easy to notice these attempts to prove “experience” in the wild: on <em>CNET, </em><a href="https://www.cnet.com/profiles/connieguglielmo/">author bios have very literal subheadings</a> like “expertise” and “credentials.” Earlier this year, <em>The New York Times</em> began adding enhanced bylines to some stories. A recent investigation into Kanye West’s business deals with Adidas reads, “For this article, Megan Twohey traveled to Portland, Ore., and Los Angeles; interviewed current and former employees of Adidas and of Kanye West; and obtained hundreds of previously undisclosed internal records.” The<em> Times </em><a href="https://www.niemanlab.org/2023/05/the-new-york-times-launches-enhanced-bylines-with-more-information-about-how-journalists-did-the-reporting/">told Nieman Lab</a> the change wasn’t prompted by Google’s policy update, but it’s just the kind of sign of trustworthiness Google likes.</p>

<p>The problem, of course, is that anyone can write up an author bio promising years of expertise — and writing that you’re an expert doesn’t make it true. In November, <em>Sports Illustrated </em>was caught publishing articles <a href="https://www.theverge.com/2023/11/27/23978389/sports-illustrated-ai-fake-authors-advon-commerce-gannett-usa-today">attributed to AI-generated authors</a>, complete with specific biographical information and what they like to do in their free time.</p>

<p class="pullquote"></p><q>The problem is that anyone can write up a bio promising years of expertise</q><p>For reputable news outlets, the challenge of producing work that Google likes <em>and </em>that meets high-quality standards is magnified; you can’t fill articles with SEO-bait keywords without readers noticing. Shelby Blackley, SEO editor at <em>The Athletic</em>, emphasizes that her work’s goal is to get reporters’ stories in front of readers without sacrificing the integrity of the journalism for Google’s algorithms.
</p><p>“The philosophy that I’ve always had is the journalism comes first. And regardless of what we try to do from a search perspective, or what Google wants, [that] is always going to be after the journalism,” Blackley tells <em>The Verge.</em></p>

<p>Blackley co-writes the popular <a href="https://www.seoforjournalism.com/"><em>WTF is SEO? </em>newsletter</a> with Jessie Willms, SEO editor at <em>The Guardian. WTF is SEO? </em>is a guide for newsroom SEO editors and audience experts who want to make sure content will reach Google users, but not at the expense of the reporting. Until recently, there were few SEO resources for people in roles like theirs, Willms says.</p>

<p>Showing Google that an author has experience in the topic will look different depending on the type of journalism, says Willms. An investigative team might create an accompanying explainer detailing how they went about requesting records, finding sources, and fact-checking their story; a laptop reviewer, meanwhile, might publish a piece explaining how they assess and test products, so readers know they can trust their reviews.</p>

<p>But even as publications double down to try to prove their experience, and AI-generated synthetic content floods platforms, Google is increasingly trusting and elevating individuals — and sometimes anonymous users. Earlier this summer, some in the SEO industry noticed that <a href="https://www.amsive.com/insights/seo/google-august-2023-core-update-winners-losers-analysis/">Reddit’s visibility on Google was skyrocketing</a>, and <a href="https://www.seroundtable.com/google-search-hidden-gems-ranking-algorithm-36388.html">Google later revealed</a> it had deployed a “hidden gems” algorithm to surface content from forums or blogs. It’s as if Google saw the discourse about adding “reddit” to the end of search queries and decided to systematize it. Google is also increasingly elevating user-generated content in Search <a href="https://techcrunch.com/2023/05/10/google-perspectives-integrates-reddit-youtube-tiktok-and-more-in-search-results/">through a “Perspectives” filter</a> that features content from TikTok and other platforms. </p>

<p>The sleazier SEO strategists have already caught on, waiting and hoping for their chance to exploit whatever Google prioritizes. There are product recommendation articles with titles like “<a href="https://web.archive.org/web/20231205230522/https://intoptrend.com/best-espresso-machine-reddit/">Best Espresso Machine Reddit 2023</a>” and entire websites filled with reviews “<a href="https://web.archive.org/web/20231206211804/https://redditconsumer.com/gaming-2/best-graphics-card-reddit/">according to Reddit</a>” that appear to be fake accounts talking to each other. Some subreddits <a href="https://www.reddit.com/r/AskConsumerAdvice/comments/13m90er/reddit_users_recommend_these_air_purifiers_in_2023/">are overrun</a> with affiliate link spam.</p>

<p>The problem with setting up an ever-scaling system of winners and losers is that someone will always try to cheat and, at least for a bit, they’ll get away with it.</p>

</div>



<div class="text-block  endmark">
<h2>5. Generative AI and the future of Search</h2>
<p>Earlier this year, Google unveiled what could become the biggest shift in how people find information online since the advent of Search: <a href="https://www.theverge.com/2023/5/10/23717120/google-search-ai-results-generated-experience-io">results generated using artificial intelligence</a>.</p>

<p>When users opt in to Search Generative Experience (SGE), Google puts AI content front and center, spitting out AI answers and placing them above organic search results. Google has experimented with how to cite sources its AI tool is pulling from, but SGE takes up valuable real estate on the results page, pushing down standard links and potentially killing publishers’ traffic. Why keep scrolling if you can find an answer to your cooking question right at the top of the page?</p>

<p>SEO experts are already thinking about how AI search might change the content they produce. Publishers could double down on creating content in categories that Google <em>won’t </em>include in SGE, for example, like health, finance, or others where the risk of getting it wrong could have negative consequences. Google calls those categories Your Money or Your Life and says <a href="https://static.googleusercontent.com/media/www.google.com/en//search/howsearchworks/google-about-SGE.pdf">SGE, like Search, requires a higher bar</a> for ranking in these areas. Publishers have a way to <a href="https://www.theverge.com/2023/9/28/23894779/google-ai-extended-training-data-toggle-bard-vertex">block Google from training its chatbot, Bard, on their work</a>, but <a href="https://www.reuters.com/technology/google-pushes-deeper-into-ai-publishers-see-fresh-challenges-2023-10-19/">there’s currently no way to opt out of SGE</a> without also disappearing from Search — a death sentence for most outlets.</p>

<p>Some bloggers are also strategizing for the coming AI wave and its potential for destabilizing their business. Zhen Zhou, who runs the cooking blog <a href="https://www.greedygirlgourmet.com/"><em>Greedy Girl Gourmet</em></a>, recently started a second site focused on traveling in Asia with elderly relatives, believing it’s a niche that is relatively untapped on Google. The hope is that the travel blog and its contents will fare better in the face of generative AI search results than Asian cooking will.</p>

<p>“Maybe after a while the AI will trawl the internet enough to give you just as good recommendations, but at least I think there’s slightly more longevity there,” Zhou says.</p>

<p class="pullquote"></p><q>“I have zero desire to satisfy a checklist for generative AI.”</q><p>But others, like Cusick, are pulling back. Instead of pivoting to write for whatever role generative AI will play in search, Cusick says she is doubling down on the tactics that work for her, which are often one-to-one, intimate interactions with potential customers.
</p><p>“I have zero desire to satisfy a checklist for generative AI or suddenly change tactics in a way that doesn’t align with my values,” she says. These days, outside of Search, Cusick has found success through in-person speaking events or private Discord communities — instead of hitching her wagon to Google and its algorithm, these avenues feel more sustainable.</p>

<p>Though Google has maintained a monopoly on search for years, there are signs that could be changing. <a href="https://www.theverge.com/23869483/us-v-google-search-antitrust-case-updates">The <em>US v. Google</em> antitrust case</a> hinges on Search, its biggest and most ubiquitous product. Other platforms like TikTok are <a href="https://www.theverge.com/23365101/tiktok-search-google-replacement">increasingly being used</a> by young people as a search engine, and the video platform has been <a href="https://www.theverge.com/2023/9/21/23884278/tiktok-google-search-results-antitrust-case">testing a partnership with Google</a> to insert search queries into TikTok results pages. </p>

<p>Publishers are already strategizing how their content will need to change as the impending generative AI takeover looms closer. But chasing algorithms <a href="https://www.theverge.com/23450270/buzzfeed-social-media-aggregation-news-digital-media">has never worked out for the media industry</a>, and increasingly, it looks like <a href="https://www.theverge.com/23846048/google-search-memes-images-pagerank-altavista-seo-keywords">this era of search online is waning</a>.</p>

<p>SEO experts like Willms and Blackley are thinking in the long term about how to reliably reach their audiences. Algorithms — and the platforms themselves — ebb and flow; what sticks around is the audience base who comes straight to you.</p>

<p>The habit of prioritizing Google is hard to break — it’s quite impossible to ignore the biggest search company in the world. And though 25 years of living in Google’s world feels eternal, it’s also a drop in the bucket. If Google knows anything, it’s that a young upstart can <a href="https://www.theverge.com/23846048/google-search-memes-images-pagerank-altavista-seo-keywords">come along and change everything</a>.</p>

<p>But no matter what happens with Search, there’s already a splintering: a web full of cheap, low-effort content and a whole world of human-first art, entertainment, and information that lives behind paywalls, in private chat rooms, and on websites that are working toward a more sustainable model. As with young people using TikTok for search, or the practice of adding “reddit” to search queries, users are signaling they want a different way to find things and feel no particular loyalty to Google.</p>

<p>It’s all but certain that a new era of content relentlessly optimized for AI search engines is bound to result in the same kinds of problems we have today. And with that realization, there is a chance at another way forward, without the almost religious dependence on Google; searching and creating for a vacillating overlord feels increasingly futile. And when the creators and searchers leave the web for good, Google will have nobody to blame but itself.</p>

</div>
