title: Infrequently Noted
url: https://infrequently.org/2018/09/the-developer-experience-bait-and-switch/
hash_url: 7bc5331346ba44306777df275aa68a2a

<p><em><strong>TL;DR</strong>: we cannot continue to use as much JavaScript as is now “normal” and expect the web to flourish. At the same time, most developers experience no constraint on their use of JS…until it’s too late. “JS neutral” and “TTI negative” tools are here, but we’re stuck in a rhetorical rut. We need to reset our conversation about “developer experience” to factor in the asymmetric cost of JS.</em></p>
<p>JavaScript is the web’s <a href="https://www.theguardian.com/environment/climate-consensus-97-per-cent/2013/sep/27/global-warming-ipcc-report-humans">CO2</a>. We need some of it, but too much puts the entire ecosystem at risk. Those who emit the most are furthest from suffering the consequences — until the ecosystem collapses. The web will not succeed in the markets and form-factors where computing is headed unless we get JS emissions under control.</p>
<p>Against this grim backdrop, there’s something peculiar about conversations regarding the costs of JS-oriented development: a rhetorical substitution of developer value for user value. Here’s a straw-man composite from several recent conversations:</p>
<blockquote>
<p>These tools let us move faster. Because we can iterate faster we’re delivering better experiences. If performance is a problem, we can do progressive enhancement through Server-Side Rendering.</p>
</blockquote>
<p>This argument substitutes good intentions and developer value (“moving faster”, “less complexity”) for questions about the lived experience of users. It also tends to do so without evidence. We’re meant to take it on faith that it will all work out if only the well intentioned people are never questioned about the trajectory of the outcomes.</p>
<p>Most unfortunately, this substitution is frequently offered to shield the preferences of those in a position to benefit at the expense of folks who can least afford to deal with the repercussions. Polluters very much prefer conversations that don’t focus on the costs of emissions.</p>
<p>The backdrop to this argument is a set of nominally shared values to which folks assign different weights:</p>
<ul>
<li>Universality and accessibility</li>
<li>Fidelity and richness</li>
<li>Competitive (or superior) cost to produce</li>
</ul>
<p>The “developer experience” bait-and-switch works by appealing to the listener’s parochial interests as developers or managers, claiming supremacy in one category in order to remove others from the conversation. The swap is executed by <em>implying</em> that by making things better for developers, users will eventually benefit equivalently. The unstated agreement is that developers share all of the same goals with the same intensity as end users and even managers. <strong><em>This is not true</em></strong>.</p>
<p>Shifting the conversation away from <em>actual</em> user experiences to team-level advantages enables a culture in which the folks who receive focus and attention are developers, rather than end-users or the business. It naturally follows that teams can then substitute <em>tools</em> for <em>goals</em>.</p>
<p>This has predictable consequences, particularly when developers, through their privileged positions as expensive-knowers-of-things-about-computers, are allowed to <a href="https://en.wikipedia.org/wiki/Externality#Negative">externalize costs</a>. And they do. Few teams I’ve encountered have actionable metrics associated with the real experiences of their users. I can count on one hand the number of teams I’ve worked with who have goals that allow them to block launches for latency regressions, including Google products. Nearly all developers in the modern frontend shops <em>do not experience performance constraints until it’s too late</em>. The brakes aren’t applied until performance is so poor that it actively hurts the business.</p>
<p>If one views the web as a way to address a fixed market of existing, wealthy web users, then it’s reasonable to bias towards richness and lower production costs. If, on the other hand, our primary challenge is in growing the web along with the growth of computing overall, the ability to reasonably access content bumps up in priority. If you believe the web’s future to be at risk due to the unusability of most web experiences for most users, then discussion of developer comfort that isn’t tied to demonstrable gains for marginalized users is at best misguided.</p>
<p>Competition between these forces is as old as debates about imagemaps vs. tables for layout. What’s new is JavaScript; or rather, <a href="https://httparchive.org/reports/state-of-javascript#bytesJs">the amount we’re applying</a> to solve our problems:</p>
<div id="attachment_2672" class="wp-caption aligncenter">
  <a href="https://httparchive.org/reports/state-of-javascript#bytesJs"><img src="https://infrequently.org/wp-content/uploads/2018/09/http_archive_js_bytes_chart-1-300x154.png" alt="Mobile pages have gone from an average of 50KB of JS in 2011 to more than 300KB today." class="size-medium wp-image-2672" srcset="https://infrequently.org/wp-content/uploads/2018/09/http_archive_js_bytes_chart-1-300x154.png 300w, https://infrequently.org/wp-content/uploads/2018/09/http_archive_js_bytes_chart-1-768x393.png 768w, https://infrequently.org/wp-content/uploads/2018/09/http_archive_js_bytes_chart-1-1024x524.png 1024w, https://infrequently.org/wp-content/uploads/2018/09/http_archive_js_bytes_chart-1.png 1178w" sizes="(max-width: 300px) 100vw, 300px"/></a>
<p class="wp-caption-text">
    Median mobile sites have gone from ~50KB of JS in 2011 to more than 350KB today. That unzips to roughly 2MB of script.
  </p>
</div>
<p>I’ve <a href="https://infrequently.org/2017/10/can-you-afford-it-real-world-web-performance-budgets/">previously outlined why JavaScript is the most expensive way to accomplish anything</a> in a browser. This has been coupled with an <a href="https://www.youtube.com/watch?v=4bZvq3nodf4">attempt to lean on evolving facts about computing (it’s all going to mobile, mostly to Android, and not high-end devices)</a>. My hope is that anyone who connects these ideas will come to understand that we can’t afford to continue on as we have. We must budget. We must cap-and-trade JS. There is no other way to fix what we have now broken with script — we simply need to use less of it.</p>
<p>There have been positive signs that this message has taken root in certain quarters, but it has not generally changed the dynamic. Despite the heroic efforts of <a href="https://github.com/Polymer/pwa-starter-kit">Polymer</a>, <a href="https://github.com/developit/preact-cli">Preact</a>, <a href="https://sapper.svelte.technology/">Svelte</a>, <a href="https://ionicframework.com/pwa/toolkit">Ionic</a>, and <a href="https://cli.vuejs.org/">Vue</a> to create companion “starter kits” or “CLI” tools that provide the structure necessary to send less JS be default, as many (or more) JS-heavy performance disasters cross my desk in an average month as in previous years.</p>
<p>And still framework marketing continues unmodified. The landing pages of popular tools talk about “speed” without context. Relatively few folks bring <a href="https://www.webpagetest.org/easy">WPT traces</a> to arguments. Appeals to “Developer Experience” are made without context. Which set of users do we intend to serve? All? Or the wealthy few? <a href="https://engineering.linkedin.com/blog/2018/03/how-we-built-the-same-app-twice-with-preact-and-glimmerjs">It is apparently possible to present performance arguments to the JavaScript community in 2018</a> — a time when it has never been easier to collect and publish traces — without traces against <a href="https://infrequently.org/2017/10/can-you-afford-it-real-world-web-performance-budgets/">the global baseline</a> or an explanation of why that baseline is inappropriate. <em>The bait-and-switch still works</em>, and that’s a hell of a problem.</p>
<p>Perhaps my arguments have not been effective because I hold to a policy of not posting analyses without site owner’s consent. This leaves me as open to critique by <a href="https://en.wikipedia.org/wiki/Hitchens%27s_razor">Hitchen’s Razor</a> as my dataless interlocutors. The evidence <a href="https://www.webpagetest.org/easy">has never been easier to gather</a> and the aggregates paint a chilling picture. But aggregates aren’t specific, citable incidents. Video of a single slow-loading page lands in a visceral way; abstract graphs don’t.</p>
<p>And the examples are there, many of them causing material, negative business impact. A decent hedge-fund strategy would be to run a private WPT instance and track JS bloat and TTI for commercial-intent sites — and then short firms that regress because they just rewrote everything in The One True Framework. Seeing the evidence instills terror, yet I’ve been hamstrung to do more than roughly sketch the unfolding disaster while working behind the scenes with teams.</p>
<p>There is, however, one exception to my rule: the public sector. Specifically public sector sites in countries where I pay taxes. Today, that’s the US and the UK, although I suspect I could be talked into a more blanket exception.</p>
<p>So I’m going to start posting and dissecting a lot more traces of public sector work, but the goal isn’t to mock or shame the fine folks doing hard work for too little pay. Rather, it’s to demonstrate what “modern frontend” is doing to the accessibility of the web — not in the traditional “a11y” sense, but in the “is going to this site reasonable for its intended users?” sense. That is, I will be talking about this as a proxy for the data I <em>can’t</em> share.</p>
<p>Luckily, the brilliant folks at the <a href="https://www.usds.gov/">USDS</a> and the <a href="https://gds.blog.gov.uk/">UK’s Government Digital Service</a> have been cleaning up many of the worst examples of government-procurement-gone-wild. My goal isn’t to detract anything from this extraordinary achievement:</p>
<blockquote class="twitter-tweet" data-width="500" data-dnt="true">
<p lang="en" dir="ltr">Just wanted to send my 💌 and 🙏 to the lovely souls at <a href="https://twitter.com/gdsteam?ref_src=twsrc%5Etfw">@gdsteam</a>.</p>
<p>I spend a lot of time despairing at what Silicon Valley thinks is acceptable and y'all are beacon on a hill, showing what's possible and what inclusion *really* means: <a href="https://t.co/vCY6sgOwee">https://t.co/vCY6sgOwee</a></p>
<p>— Alex Russell (@slightlylate) <a href="https://twitter.com/slightlylate/status/1034179822472196096?ref_src=twsrc%5Etfw">August 27, 2018</a></p></blockquote>
<p/>
<p>My hope, instead, is that by showing specific outcomes and the overwhelming volume of these examples it will become possible to talk more specifically about what’s wrong, using and pervasively citing data. I hope that by talking about what it means to build well when trying to serve everybody, we can show businesses how short they’re falling of the mark — and why those common root-causes in JS-centric development are so toxic. And if the analysis manages to help clean up some public sector services, so much the better; we’re all paying for it anyway.</p>

<p>This isn’t Plan A, but neither was the <a href="https://www.youtube.com/watch?v=4bZvq3nodf4">CDS talk in ’16 that got everyone so upset</a>. I don’t like that this is where we are as a community and as a platform. I hate that this continues to estrange me from the JS community. We need tools. We need frameworks. But we need to judge them by whether or not the deliver a better developer experience <em>without</em> fundamentally impairing the <em>user experience</em>. We must get to JS-neutral (or, my preferred, Time-to-Interactive-neutral or negative) tooling. Frameworks and tooling need to explain clearly, in small words, with reproducible instructions how they deliver <a href="https://infrequently.org/2017/10/can-you-afford-it-real-world-web-performance-budgets/">under-budget experiences</a>, how much room is left after their budgetary cost, and what devices and networks their tools are appropriate in. This will mean that many popular tools are relegated to prototyping. <em>That’s OK</em>.</p>
<p>This is very much Plan D…or E. But the crisis is real and it isn’t inevitable. It is not exogenous. We made it, and we can fix it.</p>
<p>To get this fixed, we need to confront the “developer experience” bait-and-switch. Tools that cost the poorest users to pay wealthy developers are bunk. To do better, we need to move the conversation to an evidence-based footing. I wish the arguments folks made against my positions were data-driven. There’s so much opening! Perhaps a firm <em>is</em> doing market analysis and only cares about ever reaching users who make more than $100K USD/yr or who are in enterprise settings. Perhaps research will demonstrate that interactivity isn’t as valuable as getting bits on screen (the usual SSR argument). Or, more likely, that acknowledgement (bits on screen) buys a larger-than-anticipated amount of perceptual padding (perhaps due to <a href="https://www.nngroup.com/articles/f-shaped-pattern-reading-web-content/">scanning</a>). Perhaps the global network landscape is shifting so dramatically that the budget for client-side JS runtime has increased. Perhaps the median CPU improvement that doesn’t look set to materialize until 2021 at the earliest will happen much earlier; i.e., maybe the current baseline is wrong!</p>
<p>But we aren’t having that conversation. And we aren’t going to have it until we identify, call-out, and end the “developer experience” bait-and-switch.</p>
<p><em>Thanks and apologies to <a href="https://twitter.com/ade_oshineye">Ade Oshineye</a>, <a href="https://twitter.com/ojanvafai">Ojan Vafai</a>, <a href="https://fberriman.com/">Frances Berriman</a>, <a href="https://twitter.com/dalmaer">Dion Almaer</a>, <a href="https://twitter.com/addyosmani">Addy Osmani</a>, <a href="https://twitter.com/graynorton">Gray Norton</a> and <a href="https://twitter.com/philwalton">Philip Walton</a> for their feedback on drafts of this post.</em></p>
