title: Développer efficacement avec Git
url: http://www.occitech.fr/blog/2014/12/un-modele-de-branches-git-efficace/
hash_url: 7dfecff06cb91feccce15d23301c09e8

<p><em>NdT : Depuis 2 ans, notre équipe utilise <a href="https://github.com/nvie/gitflow">Gitflow</a>, un modèle de développement simple, documenté dans cet article. Cette convention facilite entre autres le déploiement continu. Nous vous encourageons à l’adopter à votre tour.</em></p>

<p><em>Nous avons donc traduit <a href="http://nvie.com/posts/a-successful-git-branching-model/">l’article original</a> de Vincent Driessen à destination des équipes agiles francophones.</em></p>
<p>Dans cet article je présente le modèle de développement que j’ai commencé à utiliser pour tous mes projets (professionnels et personnels) depuis 1 an, et qui s’est avéré être très efficace. Cela fait un moment que je voulais écrire à son propos, mais je n’avais pas vraiment tout à fait pris le temps de le faire, jusqu’à maintenant. Je ne vais pas parler des détails des projets, simplement de la stratégie de ramification des branches et de la gestion des versions.</p>
<p><img src="http://nvie.com/img/git-model@2x.png" alt="modèle de branches Git"/></p>
<p>C’est axé autour de Git comme outil de versionnement pour tout le code source.</p>
<h2>Pourquoi Git ?</h2>
<p>Pour une discussion approfondie sur les avantages et les inconvénients de Git comparé à des systèmes centralisés de contrôle du code source, <a href="http://www.whygitisbetterthanx.com">regardez</a> sur le <a href="https://git.wiki.kernel.org/index.php/GitSvnComparsion">web</a>. Il y a plein d’échanges de points de vue qui continuent sur le web.</p>
<p>En tant que développeur, je préfère Git à tous les autres outils qui existent aujourd’hui. Git a vraiment changé la manière dont les développeurs pensent la fusion et la bifurcation de branche. Dans le monde des classiques CVS/ Subversion d’où je viens, fusionner/ramifier a toujours été considéré comme quelque chose d’un peu effrayant (attention aux conflits après une fusion, ils mordent !) et c’est une opération qu’on ne fait que de temps à autre.</p>
<p>Mais avec Git, ces opérations sont très peu coûteuses et très simples et elles sont vraiment considérées comme partie intégrante de votre manière de travailler au quotidien. Par exemple dans les <a href="http://svnbook.red-bean.com">livres</a> sur CVS/Subversion, la création de branche et la fusion ne sont évoquées que dans les derniers chapitres (pour les utilisateurs avancés), alors que dans <a href="https://pragprog.com/book/tsgit/pragmatic-version-control-using-git">n’importe quel livre sur Git</a>, c’est un sujet couvert dès le chapitre 3 (les bases).</p>
<p>Grâce à sa simplicité et à sa nature répétitive, la bifurcation et la fusion ne sont plus une opération à redouter. Les outils de contrôle de version sont avant tout supposés aider dans la bifurcation/fusion.</p>
<p>Assez parlé des outils, voyons maintenant le modèle de développement. Le modèle que je présente ici n’est rien d’autre qu’un ensemble de procédures que chaque membre de l’équipe doit respecter pour parvenir à un processus de gestion de développement logiciel.</p>
<h2>Décentralisé mais centralisé</h2>
<p>La configuration de dépôt que nous utilisons et qui marche bien avec ce modèle de développement, est celle avec un « vrai » dépôt central. Notez que ce dépôt est simplement <em>considéré</em> comme étant le dépôt central (puisque Git est un système de version décentralisé, techniquement il n’existe pas de dépôt central en tant que tel.). Nous ferons référence à ce dépôt comme &#13;
			<span id="crayon-5524f18329960220084663" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">origin</span></span></span>, puisque tous les utilisateurs de Git sont familiers avec ce nom.</p>
<p><img src="http://nvie.com/img/centr-decentr@2x.png" alt="Des dépôts centralisés et un dépôt central"/></p>
<p>Chaque développeur &#13;
			<span id="crayon-5524f1832996a951613731" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">pull</span></span></span> et &#13;
			<span id="crayon-5524f1832996d933763346" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">push</span></span></span> sur &#13;
			<span id="crayon-5524f18329971850647940" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">origin</span></span></span>. Mais au delà de la relation centralisée push-pull, chaque développeur peut aussi récupérer des changements d’autres équipiers et ainsi former des sous-équipes. Par exemple, cela peut s’avérer utile quand deux ou plusieurs développeurs travaillent ensemble sur une fonctionnalité, plutôt que de pousser prématurément le travail en cours sur &#13;
			<span id="crayon-5524f18329974202447255" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">origin</span></span></span>. Dans l’illustration ci-dessus,  il y a des sous-équipes d’Alice et Bob, Alice et David et Claire et David.</p>
<p>Techniquement, cela veut simplement dire qu’Alice a défini un dépôt distant, nommé &#13;
			<span id="crayon-5524f18329977827858655" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">bob</span></span></span>, qui pointe vers le dépôt de Bob et inversement.</p>
<h2>Les branches principales</h2>
<p>À la base, ce modèle de développement s’inspire fortement de modèles existants. Le dépôt central héberge les deux branches principales qui ont une durée de vie infinie :</p>

<p>La branche &#13;
			<span id="crayon-5524f18329981433630635" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span> sur &#13;
			<span id="crayon-5524f18329983132954111" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">origin</span></span></span> devrait être connue des utilisateurs de Git. Parallèlement à la branche &#13;
			<span id="crayon-5524f18329986929081415" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span>, une autre branche appelée &#13;
			<span id="crayon-5524f18329989667513460" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> est présente.</p>
<p>Nous considérons &#13;
			<span id="crayon-5524f1832998c094138297" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">origin</span><span class="crayon-o">/</span><span class="crayon-i">master</span></span></span> comme étant la branche principale où le code source de &#13;
			<span id="crayon-5524f18329990621208088" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-cn">HEAD</span></span></span> reflète l’état de <em>prêt pour être déployé en production</em>.</p>
<p>Nous considérons &#13;
			<span id="crayon-5524f18329993395315804" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">origin</span><span class="crayon-o">/</span><span class="crayon-i">develop</span></span></span> comme étant la branche principale où le code source de &#13;
			<span id="crayon-5524f18329996971374370" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-cn">HEAD</span></span></span> reflète les derniers changements livrés pour la prochaine version. Certains l’appelleraient « branche d’intégration ». C’est à partir de cet emplacement que sont compilées les versions quotidiennes.</p>
<p>Quand le code source dans la branche &#13;
			<span id="crayon-5524f18329999187104857" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> est considéré stable et prête à être livré, tous les changements doivent être fusionnés dans &#13;
			<span id="crayon-5524f1832999c838494319" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span> puis se voient assignés d’un numéro de version. Nous verrons comment faire cela en détails plus loin.</p>
<p>En conséquence, à chaque fois que des changements sont reportés dans &#13;
			<span id="crayon-5524f1832999f954198507" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span>, <em>par définition</em> c’est une nouvelle version de production. Nous devons être très strict avec ceci, pour qu’hypothétiquement nous puissions utiliser un hook Git afin de compiler et déployer automatiquement notre logiciel sur nos serveurs de production à chaque fois qu’il y a un commit sur &#13;
			<span id="crayon-5524f183299a2504499913" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span>.</p>
<h2>Les branches de support</h2>
<p>A côté des branches principales &#13;
			<span id="crayon-5524f183299a5711933447" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span> et &#13;
			<span id="crayon-5524f183299a8210986753" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span>, notre modèle de développement utilise une variété de branches de support pour aider le développement en parallèle entre les membres de l’équipe, faciliter le suivi des fonctionnalités, préparer les versions de productions et nous aider à réparer rapidement les problèmes survenus en production.<br/>
Contrairement aux branches principales, ces branches ont toujours une durée de vie limitée, puisqu’elles seront effacées au final.</p>
<p>Les différents types de branches que nous pouvons utiliser sont :</p>
<ul>
<li>les branches pour les fonctionnalités</li>
<li>les branches pour les versions</li>
<li>les branches de correctifs</li>
</ul>
<p>Chacune de ces branches a un but précis et elles obéissent à des règles strictes comme de quelles branches elles peuvent provenir et dans quelles branches elles peuvent être fusionnées. Nous allons voir comment dans quelques minutes.</p>
<p>Ce ne sont en aucun cas des branches « spéciales » d’un point de vue technique. Les types de branche sont catégorisés par la façon dont nous les <em>utilisons</em>. Ce sont bien sûr de bonnes vieilles branches Git.</p>
<h2>Les branches de fonctionnalité</h2>
<dl>
<dt>Peuvent provenir de :</dt>
<dd>&#13;
			<span id="crayon-5524f183299ac643994389" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span></dd>
<dt>Doivent être fusionnées dans :</dt>
<dd>&#13;
			<span id="crayon-5524f183299af497600238" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span></dd>
<dt>Convention de nommage de la branche :</dt>
<dd>Tout sauf &#13;
			<span id="crayon-5524f183299b2244283822" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span>, &#13;
			<span id="crayon-5524f183299b5685611838" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span>, &#13;
			<span id="crayon-5524f183299b8798246908" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">release</span><span class="crayon-o">-</span><span class="crayon-o">*</span></span></span> ou &#13;
			<span id="crayon-5524f183299bb271658553" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">hotfix</span><span class="crayon-o">-</span><span class="crayon-o">*</span></span></span>.</dd>
</dl>
<p>Les branches de fonctionnalités (parfois appelées branches de thème) sont utilisées pour développer de nouvelles fonctionnalités pour la prochaine version ou pour une future. Au début du développement d’une fonctionnalité, la version cible dans laquelle cette fonctionnalité sera ajoutée peut très bien être inconnue à cet instant. La raison d’être d’une branche de fonctionnalité est qu’elle existe tant que la fonctionnalité est en cours de développement, mais sera finalement fusionnée dans &#13;
			<span id="crayon-5524f183299be125860865" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> (pour ajouter la fonctionnalité à la prochaine version) ou abandonnée (dans le cas d’une expérience décevante).</p>
<p>Les branches de fonctionnalités n’existent typiquement que dans les dépôts des développeurs, pas sur &#13;
			<span id="crayon-5524f183299c1038681621" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">origin</span></span></span>.</p>
<h3>Créer une branche de fonctionnalité</h3>
<p>Lorsque vous commencee à travailler sur une nouvelle fonctionnalité, partez de la branche &#13;
			<span id="crayon-5524f183299c5094065692" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span>
</p>&#13;
&#13;
		<div id="crayon-5524f183299c8700863381" class="crayon-syntax crayon-theme-github crayon-font-monaco crayon-os-pc print-yes notranslate" data-settings=" minimize scroll-mouseover">&#13;
		&#13;
			&#13;
			<p class="crayon-info"/>&#13;
			<p class="crayon-plain-wrap"/>&#13;
			<div class="crayon-main">&#13;
				<table class="crayon-table">&#13;
					<tr class="crayon-row">&#13;
				<td class="crayon-nums " data-settings="show">&#13;
					&#13;
				</td>&#13;
						<td class="crayon-code"><div class="crayon-pre"><p class="crayon-line" id="crayon-5524f183299c8700863381-1"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">checkout</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">b</span><span class="crayon-h"> </span><span class="crayon-e">myfeature </span><span class="crayon-e">develop</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f183299c8700863381-2"><span class="crayon-e">Switched </span><span class="crayon-st">to</span><span class="crayon-h"> </span><span class="crayon-i">a</span><span class="crayon-h"> </span><span class="crayon-r">new</span><span class="crayon-h"> </span><span class="crayon-i">branch</span><span class="crayon-h"> </span><span class="crayon-s">"myfeature"</span></p></div></td>&#13;
					</tr>&#13;
				</table>&#13;
			</div>&#13;
		</div>&#13;
&#13;
<p>
</p><h3>Incorporer une fonctionnalité terminée dans develop</h3>
<p>Les fonctionnalités terminées peuvent être fusionnées dans la branche &#13;
			<span id="crayon-5524f183299cb046223666" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> pour être ajoutées à la prochaine version :</p>
&#13;
&#13;
		<div id="crayon-5524f183299ce356317238" class="crayon-syntax crayon-theme-github crayon-font-monaco crayon-os-pc print-yes notranslate" data-settings=" minimize scroll-mouseover">&#13;
		&#13;
			&#13;
			<p class="crayon-info"/>&#13;
			<p class="crayon-plain-wrap"/>&#13;
			<div class="crayon-main">&#13;
				<table class="crayon-table">&#13;
					<tr class="crayon-row">&#13;
				<td class="crayon-nums " data-settings="show">&#13;
					&#13;
				</td>&#13;
						<td class="crayon-code"><div class="crayon-pre"><p class="crayon-line" id="crayon-5524f183299ce356317238-1"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-e">checkout </span><span class="crayon-e">develop</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f183299ce356317238-2"><span class="crayon-e">Switched </span><span class="crayon-st">to</span><span class="crayon-h"> </span><span class="crayon-i">branch</span><span class="crayon-h"> </span><span class="crayon-s">'develop'</span></p><p class="crayon-line" id="crayon-5524f183299ce356317238-3"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">merge</span><span class="crayon-h"> </span><span class="crayon-o">--</span><span class="crayon-i">no</span><span class="crayon-o">-</span><span class="crayon-e">ff </span><span class="crayon-e">myfeature</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f183299ce356317238-4"><span class="crayon-e">Updating </span><span class="crayon-i">ea1b82a</span><span class="crayon-sy">.</span><span class="crayon-sy">.</span><span class="crayon-cn">05e9557</span></p><p class="crayon-line" id="crayon-5524f183299ce356317238-5"><span class="crayon-sy">(</span><span class="crayon-cn">R</span>é<span class="crayon-i">sum</span>é<span class="crayon-h"> </span><span class="crayon-e">des </span><span class="crayon-i">changements</span><span class="crayon-sy">)</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f183299ce356317238-6"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">branch</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">d</span><span class="crayon-h"> </span><span class="crayon-e">myfeature</span></p><p class="crayon-line" id="crayon-5524f183299ce356317238-7"><span class="crayon-e">Deleted </span><span class="crayon-e">branch </span><span class="crayon-e">myfeature</span><span class="crayon-h"> </span><span class="crayon-sy">(</span><span class="crayon-i">was</span><span class="crayon-h"> </span><span class="crayon-cn">05e9557</span><span class="crayon-sy">)</span><span class="crayon-sy">.</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f183299ce356317238-8"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-e">push </span><span class="crayon-e">origin </span><span class="crayon-i">develop</span></p></div></td>&#13;
					</tr>&#13;
				</table>&#13;
			</div>&#13;
		</div>&#13;
&#13;

<p>L’option &#13;
			<span id="crayon-5524f183299d1207435428" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-o">--</span><span class="crayon-i">no</span><span class="crayon-o">-</span><span class="crayon-i">ff</span></span></span> va créer un nouveau commit lors de la fusion, même si la fusion aurait pu se faire avec un fast-forward. Cela évite de perdre l’information de l’existence historique d’une branche de fonctionnalité et groupe ensemble tous les commits qui ont été ajoutés à la fonctionnalité.</p>
<p>Regardez la différence :</p>
<p><img src="http://nvie.com/img/merge-without-ff@2x.png" alt="Fusion avec et sans l’option fast-foward"/></p>
<p>Dans le deuxième cas, il est impossible de voir à partir de l’historique de Git quel groupe de commits a implémenté une fonctionnalité – il faudrait lire manuellement tous les messages de logs. Supprimer une fonctionnalité (c’est à dire un ensemble de commits) est un vrai casse-tête dans la deuxième situation, alors que c’est très facile à faire lorque l’option &#13;
			<span id="crayon-5524f183299d4580809159" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-o">--</span><span class="crayon-i">no</span><span class="crayon-o">-</span><span class="crayon-i">ff</span></span></span> a été utilisée.</p>
<p>Oui, cela va créer quelques commits (vides) supplémentaires, mais le gain est tellement supérieur au coût.</p>
<p>Malheureusement, je n’ai pas encore trouvé de manière de faire de &#13;
			<span id="crayon-5524f183299d7714061467" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-o">--</span><span class="crayon-i">no</span><span class="crayon-o">-</span><span class="crayon-i">ff</span></span></span> l’option par défaut de git merge, mais ça devrait vraiment l’être.</p>
<h2>Les branches de version</h2>
<dl>
<dt>Peuvent provenir de :</dt>
<dd>&#13;
			<span id="crayon-5524f183299da002474249" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span></dd>
<dt>Doivent être fusionnées dans :</dt>
<dd>&#13;
			<span id="crayon-5524f183299dd657154296" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> et &#13;
			<span id="crayon-5524f183299e0817444121" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span></dd>
<dt>Convention de nommage de la branche :</dt>
<dd>&#13;
			<span id="crayon-5524f183299e3211039715" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">release</span><span class="crayon-o">-</span><span class="crayon-o">*</span></span></span></dd>
</dl>
<p>Les branches de version servent à préparer les nouvelles versions de production. Elles permettent les optimisations de dernière minute. De plus elles permettent la correction d’anomalies mineures et la préparation des méta-données pour une version (numéro, date de compilation, etc.). En faisant tout ce travail sur une branche de version, la branche &#13;
			<span id="crayon-5524f183299e7416678574" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> peut incorporer des fonctionnalités pour la prochaine version majeure.</p>
<p>Le bon moment pour créer une nouvelle branche de version depuis &#13;
			<span id="crayon-5524f183299ea065516621" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> est quand &#13;
			<span id="crayon-5524f183299ed306026670" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> reflète l’état désiré de la nouvelle version. A minima toutes les fonctionnalités visées pour la version à venir doivent être fusionnées dans &#13;
			<span id="crayon-5524f183299f0030554742" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> à ce moment-là. Toutes les fonctionnalités visées pour les prochaines versions ne le sont pas – elles doivent attendre jusqu’à ce que la branche de version bifurque.</p>
<p>C’est précisément au début d’une branche de version que la prochaine version se voit assigné un numéro de version – et pas avant. Avant ce moment, la branche &#13;
			<span id="crayon-5524f183299f3156614501" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> reflète les changements pour la « prochaine version » mais sans forcément savoir si cette « prochaine version » sera la 0.3 ou la 1.0, du moins pas avant que la branche de version soit créé. Cette décision est prise au début de la nouvelle branche de version et dépend des règles mise en place sur les changements de numéros de version.</p>
<h3>Créer une branche de version</h3>
<p>Les branches de version sont créées à partir de la branche &#13;
			<span id="crayon-5524f183299f6836842602" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span>. Par exemple, disons que la version 1.1.5 est la version courante de production et que nous avons une nouvelle version majeure qui arrive. L’état de &#13;
			<span id="crayon-5524f183299f9481142192" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> est prêt pour la « prochaine version » et nous avons décidé que cela deviendra la version 1.2 (plutôt que 1.1.6 ou 2.0). Donc nous bifurquons et donnons à la branche de version un nom qui reflète le nouveau numéro de version :</p>
&#13;
&#13;
		<div id="crayon-5524f183299fc564838810" class="crayon-syntax crayon-theme-github crayon-font-monaco crayon-os-pc print-yes notranslate" data-settings=" minimize scroll-mouseover">&#13;
		&#13;
			&#13;
			<p class="crayon-info"/>&#13;
			<p class="crayon-plain-wrap"/>&#13;
			<div class="crayon-main">&#13;
				<table class="crayon-table">&#13;
					<tr class="crayon-row">&#13;
				<td class="crayon-nums " data-settings="show">&#13;
					&#13;
				</td>&#13;
						<td class="crayon-code"><div class="crayon-pre"><p class="crayon-line" id="crayon-5524f183299fc564838810-1"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">checkout</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">b</span><span class="crayon-h"> </span><span class="crayon-i">release</span><span class="crayon-o">-</span><span class="crayon-cn">1.2</span><span class="crayon-h"> </span><span class="crayon-e">develop</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f183299fc564838810-2"><span class="crayon-e">Switched </span><span class="crayon-st">to</span><span class="crayon-h"> </span><span class="crayon-i">a</span><span class="crayon-h"> </span><span class="crayon-r">new</span><span class="crayon-h"> </span><span class="crayon-i">branch</span><span class="crayon-h"> </span><span class="crayon-s">"release-1.2"</span></p><p class="crayon-line" id="crayon-5524f183299fc564838810-3"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-sy">.</span><span class="crayon-o">/</span><span class="crayon-i">bump</span><span class="crayon-o">-</span><span class="crayon-i">version</span><span class="crayon-sy">.</span><span class="crayon-i">sh</span><span class="crayon-h"> </span><span class="crayon-cn">1.2</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f183299fc564838810-4"><span class="crayon-e">Files </span><span class="crayon-e">modified </span><span class="crayon-i">successfully</span><span class="crayon-sy">,</span><span class="crayon-h"> </span><span class="crayon-e">version </span><span class="crayon-e">bumped </span><span class="crayon-st">to</span><span class="crayon-h"> </span><span class="crayon-cn">1.2.</span></p><p class="crayon-line" id="crayon-5524f183299fc564838810-5"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">commit</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">a</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">m</span><span class="crayon-h"> </span><span class="crayon-s">"Bumped version number to 1.2"</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f183299fc564838810-6"><span class="crayon-sy">[</span><span class="crayon-i">release</span><span class="crayon-o">-</span><span class="crayon-cn">1.2</span><span class="crayon-h"> </span><span class="crayon-cn">74d9424</span><span class="crayon-sy">]</span><span class="crayon-h"> </span><span class="crayon-e">Bumped </span><span class="crayon-e">version </span><span class="crayon-e">number </span><span class="crayon-st">to</span><span class="crayon-h"> </span><span class="crayon-cn">1.2</span></p><p class="crayon-line" id="crayon-5524f183299fc564838810-7"><span class="crayon-cn">1</span><span class="crayon-h"> </span><span class="crayon-e">files </span><span class="crayon-i">changed</span><span class="crayon-sy">,</span><span class="crayon-h"> </span><span class="crayon-cn">1</span><span class="crayon-h"> </span><span class="crayon-e">insertions</span><span class="crayon-sy">(</span><span class="crayon-o">+</span><span class="crayon-sy">)</span><span class="crayon-sy">,</span><span class="crayon-h"> </span><span class="crayon-cn">1</span><span class="crayon-h"> </span><span class="crayon-e">deletions</span><span class="crayon-sy">(</span><span class="crayon-o">-</span><span class="crayon-sy">)</span></p></div></td>&#13;
					</tr>&#13;
				</table>&#13;
			</div>&#13;
		</div>&#13;
&#13;

<p>Après avoir crée une nouvelle branche, et nous être positionné dessus, nous incrémentons le numéro de version. Ici, &#13;
			<span id="crayon-5524f183299ff973330345" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">bump</span><span class="crayon-o">-</span><span class="crayon-i">version</span><span class="crayon-sy">.</span><span class="crayon-i">sh</span></span></span> est un script shell fictif qui change quelques fichiers dans notre dossier de travail pour refléter la nouvelle version. (Cela peut bien évidemment être un changement manuel – le propos étant que <em>certains</em> fichiers changent.) Puis, le changement de numéro de version est enregistré.</p>
<p>Cette nouvelle branche pourra exister pendant un moment, jusqu’à ce que la version soit déployée pour de bon. Pendant ce temps, des correctifs pourront être appliqués à cette branche (plutôt que sur la branche &#13;
			<span id="crayon-5524f18329a03209989767" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span>), et par conséquent en attendant la prochaine version majeure.</p>
<h3>Finaliser une branche de version</h3>
<p>Quand l’état de la branche de version est prêt à devenir une vraie version, quelques actions doivent êtres effectuées. Premièrement, la branche de release est fusionnée dans &#13;
			<span id="crayon-5524f18329a06492449599" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span> (puisque chaque commit sur &#13;
			<span id="crayon-5524f18329a09723314436" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span> est une nouvelle version <em>par définition</em>, souvenez-vous). Ensuite, ce commit sur &#13;
			<span id="crayon-5524f18329a0c616510063" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span> doit être tagué pour  pouvoir faire simplement référence par la suite à cette version historique. Enfin, les changements fais sur la branche de version doivent être reversés dans &#13;
			<span id="crayon-5524f18329a0f296433887" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span>, afin que les version futures contiennent aussi ces correctifs.</p>
<p>Les deux premieres étapes dans Git :</p>
&#13;
&#13;
		<div id="crayon-5524f18329a12992468861" class="crayon-syntax crayon-theme-github crayon-font-monaco crayon-os-pc print-yes notranslate" data-settings=" minimize scroll-mouseover">&#13;
		&#13;
			&#13;
			<p class="crayon-info"/>&#13;
			<p class="crayon-plain-wrap"/>&#13;
			<div class="crayon-main">&#13;
				<table class="crayon-table">&#13;
					<tr class="crayon-row">&#13;
				<td class="crayon-nums " data-settings="show">&#13;
					&#13;
				</td>&#13;
						<td class="crayon-code"><div class="crayon-pre"><p class="crayon-line" id="crayon-5524f18329a12992468861-1"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-e">checkout </span><span class="crayon-e">master</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a12992468861-2"><span class="crayon-e">Switched </span><span class="crayon-st">to</span><span class="crayon-h"> </span><span class="crayon-i">branch</span><span class="crayon-h"> </span><span class="crayon-s">'master'</span></p><p class="crayon-line" id="crayon-5524f18329a12992468861-3"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">merge</span><span class="crayon-h"> </span><span class="crayon-o">--</span><span class="crayon-i">no</span><span class="crayon-o">-</span><span class="crayon-e">ff </span><span class="crayon-i">release</span><span class="crayon-o">-</span><span class="crayon-cn">1.2</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a12992468861-4"><span class="crayon-e">Merge </span><span class="crayon-e">made </span><span class="crayon-e">by </span><span class="crayon-i">recursive</span><span class="crayon-sy">.</span></p><p class="crayon-line" id="crayon-5524f18329a12992468861-5"><span class="crayon-sy">(</span><span class="crayon-cn">R</span>é<span class="crayon-i">sum</span>é<span class="crayon-h"> </span><span class="crayon-e">des </span><span class="crayon-i">changements</span><span class="crayon-sy">)</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a12992468861-6"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">tag</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">a</span><span class="crayon-h"> </span><span class="crayon-cn">1.2</span></p></div></td>&#13;
					</tr>&#13;
				</table>&#13;
			</div>&#13;
		</div>&#13;
&#13;

<p>La version est maintenant terminée et taguée pour toute référence future.</p>
<p>Remarque : Vous pouvez tout aussi bien vouloir utiliser les options &#13;
			<span id="crayon-5524f18329a15062153907" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-o">-</span><span class="crayon-i">s</span></span></span> or &#13;
			<span id="crayon-5524f18329a18779032012" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-o">-</span><span class="crayon-i">u</span></span></span> &#13;
			<span id="crayon-5524f18329a1b034256407" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-o">&lt;</span><span class="crayon-i">clef</span><span class="crayon-o">&gt;</span></span></span> pour signer votre tag de manière chiffrée.</p>
<p>Pour garder les changements effectués dans la branche de version, nous avons besoin de les fusionner dans &#13;
			<span id="crayon-5524f18329a1e753025917" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span>. Avec Git :</p>
&#13;
&#13;
		<div id="crayon-5524f18329a21059551202" class="crayon-syntax crayon-theme-github crayon-font-monaco crayon-os-pc print-yes notranslate" data-settings=" minimize scroll-mouseover">&#13;
		&#13;
			&#13;
			<p class="crayon-info"/>&#13;
			<p class="crayon-plain-wrap"/>&#13;
			<div class="crayon-main">&#13;
				<table class="crayon-table">&#13;
					<tr class="crayon-row">&#13;
				<td class="crayon-nums " data-settings="show">&#13;
					&#13;
				</td>&#13;
						<td class="crayon-code"><div class="crayon-pre"><p class="crayon-line" id="crayon-5524f18329a21059551202-1"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-e">checkout </span><span class="crayon-e">develop</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a21059551202-2"><span class="crayon-e">Switched </span><span class="crayon-st">to</span><span class="crayon-h"> </span><span class="crayon-i">branch</span><span class="crayon-h"> </span><span class="crayon-s">'develop'</span></p><p class="crayon-line" id="crayon-5524f18329a21059551202-3"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">merge</span><span class="crayon-h"> </span><span class="crayon-o">--</span><span class="crayon-i">no</span><span class="crayon-o">-</span><span class="crayon-e">ff </span><span class="crayon-i">release</span><span class="crayon-o">-</span><span class="crayon-cn">1.2</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a21059551202-4"><span class="crayon-e">Merge </span><span class="crayon-e">made </span><span class="crayon-e">by </span><span class="crayon-i">recursive</span><span class="crayon-sy">.</span></p><p class="crayon-line" id="crayon-5524f18329a21059551202-5"><span class="crayon-sy">(</span><span class="crayon-cn">R</span>é<span class="crayon-i">sum</span>é<span class="crayon-h"> </span><span class="crayon-e">des </span><span class="crayon-i">changements</span><span class="crayon-sy">)</span></p></div></td>&#13;
					</tr>&#13;
				</table>&#13;
			</div>&#13;
		</div>&#13;
&#13;

<p>Cette étape peut mener à une conflit de fusion (probablement même, puisque nous avons changé le numéro de version. Si c’est le cas, corrigez-le et faîtes un commit.</p>
<p>Maintenant nous avons vraiment terminé et la branche de version peut être supprimée, puisque nous n’en avons plus besoin :</p>
&#13;
&#13;
		<div id="crayon-5524f18329a24711392903" class="crayon-syntax crayon-theme-github crayon-font-monaco crayon-os-pc print-yes notranslate" data-settings=" minimize scroll-mouseover">&#13;
		&#13;
			&#13;
			<p class="crayon-info"/>&#13;
			<p class="crayon-plain-wrap"/>&#13;
			<div class="crayon-main">&#13;
				<table class="crayon-table">&#13;
					<tr class="crayon-row">&#13;
				<td class="crayon-nums " data-settings="show">&#13;
					&#13;
				</td>&#13;
						<td class="crayon-code"><div class="crayon-pre"><p class="crayon-line" id="crayon-5524f18329a24711392903-1"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">branch</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">d</span><span class="crayon-h"> </span><span class="crayon-i">release</span><span class="crayon-o">-</span><span class="crayon-cn">1.2</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a24711392903-2"><span class="crayon-e">Deleted </span><span class="crayon-e">branch </span><span class="crayon-i">release</span><span class="crayon-o">-</span><span class="crayon-cn">1.2</span><span class="crayon-h"> </span><span class="crayon-sy">(</span><span class="crayon-e">was </span><span class="crayon-i">ff452fe</span><span class="crayon-sy">)</span><span class="crayon-sy">.</span></p></div></td>&#13;
					</tr>&#13;
				</table>&#13;
			</div>&#13;
		</div>&#13;
&#13;

<h3>Les branches de correctifs</h3>
<dl>
<dt>Peuvent provenir de :</dt>
<dd>&#13;
			<span id="crayon-5524f18329a27779043643" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span></dd>
<dt>Doivent être fusionnées dans :</dt>
<dd>&#13;
			<span id="crayon-5524f18329a2a439073976" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> et &#13;
			<span id="crayon-5524f18329a2d861174094" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span></dd>
<dt>Convention de nommage de la branche :</dt>
<dd>&#13;
			<span id="crayon-5524f18329a30801517913" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">hotfix</span><span class="crayon-o">-</span><span class="crayon-o">*</span></span></span></dd>
</dl>
<p><img src="http://nvie.com/img/hotfix-branches@2x.png" alt="Une branche de correctif"/></p>
<p>Les branches de correctifs ressemblent beaucoup aux branches de version, dans le sens où elles sont également destinées à préparer une nouvelle version de production, bien que non planifiées. Elles viennent de la nécessité d’agir immédiatement sur un état indésirable d’une version en production. Quand une anomalie critique doit être résolu immédiatement, une branche de  correctif peut être crée à partir du tag correspondant sur la branche master qui marque la version de production.</p>
<p>L’objectif est que le travail des membres de l’équipe (sur la branche &#13;
			<span id="crayon-5524f18329a33419898162" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span>) puisse continuer, pendant qu’une autre personne prépare un correctif rapide pour la production.</p>
<h3>Créer une branche de correctif</h3>
<p>Les branches de correctif sont créées à partir de la branche &#13;
			<span id="crayon-5524f18329a36595034680" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span>. Par exemple, disons que la version 1.2 est la version qui tourne actuellement en production et que plusieurs anomalies posent problème. Dans le même temps les modifications effectuées sur &#13;
			<span id="crayon-5524f18329a3a600800921" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> sont encore instables. Nous pouvons alors créer une branche de correctif et commencer à corriger le problème :</p>
&#13;
&#13;
		<div id="crayon-5524f18329a3d378202537" class="crayon-syntax crayon-theme-github crayon-font-monaco crayon-os-pc print-yes notranslate" data-settings=" minimize scroll-mouseover">&#13;
		&#13;
			&#13;
			<p class="crayon-info"/>&#13;
			<p class="crayon-plain-wrap"/>&#13;
			<div class="crayon-main">&#13;
				<table class="crayon-table">&#13;
					<tr class="crayon-row">&#13;
				<td class="crayon-nums " data-settings="show">&#13;
					&#13;
				</td>&#13;
						<td class="crayon-code"><div class="crayon-pre"><p class="crayon-line" id="crayon-5524f18329a3d378202537-1"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">checkout</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">b</span><span class="crayon-h"> </span><span class="crayon-i">hotfix</span><span class="crayon-o">-</span><span class="crayon-cn">1.2.1</span><span class="crayon-h"> </span><span class="crayon-e">master</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a3d378202537-2"><span class="crayon-e">Switched </span><span class="crayon-st">to</span><span class="crayon-h"> </span><span class="crayon-i">a</span><span class="crayon-h"> </span><span class="crayon-r">new</span><span class="crayon-h"> </span><span class="crayon-i">branch</span><span class="crayon-h"> </span><span class="crayon-s">"hotfix-1.2.1"</span></p><p class="crayon-line" id="crayon-5524f18329a3d378202537-3"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-sy">.</span><span class="crayon-o">/</span><span class="crayon-i">bump</span><span class="crayon-o">-</span><span class="crayon-i">version</span><span class="crayon-sy">.</span><span class="crayon-i">sh</span><span class="crayon-h"> </span><span class="crayon-cn">1.2.1</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a3d378202537-4"><span class="crayon-e">Files </span><span class="crayon-e">modified </span><span class="crayon-i">successfully</span><span class="crayon-sy">,</span><span class="crayon-h"> </span><span class="crayon-e">version </span><span class="crayon-e">bumped </span><span class="crayon-st">to</span><span class="crayon-h"> </span><span class="crayon-cn">1.2.1.</span></p><p class="crayon-line" id="crayon-5524f18329a3d378202537-5"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">commit</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">a</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">m</span><span class="crayon-h"> </span><span class="crayon-s">"Bumped version number to 1.2.1"</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a3d378202537-6"><span class="crayon-sy">[</span><span class="crayon-i">hotfix</span><span class="crayon-o">-</span><span class="crayon-cn">1.2.1</span><span class="crayon-h"> </span><span class="crayon-cn">41e61bb</span><span class="crayon-sy">]</span><span class="crayon-h"> </span><span class="crayon-e">Bumped </span><span class="crayon-e">version </span><span class="crayon-e">number </span><span class="crayon-st">to</span><span class="crayon-h"> </span><span class="crayon-cn">1.2.1</span></p><p class="crayon-line" id="crayon-5524f18329a3d378202537-7"><span class="crayon-cn">1</span><span class="crayon-h"> </span><span class="crayon-e">files </span><span class="crayon-i">changed</span><span class="crayon-sy">,</span><span class="crayon-h"> </span><span class="crayon-cn">1</span><span class="crayon-h"> </span><span class="crayon-e">insertions</span><span class="crayon-sy">(</span><span class="crayon-o">+</span><span class="crayon-sy">)</span><span class="crayon-sy">,</span><span class="crayon-h"> </span><span class="crayon-cn">1</span><span class="crayon-h"> </span><span class="crayon-e">deletions</span><span class="crayon-sy">(</span><span class="crayon-o">-</span><span class="crayon-sy">)</span></p></div></td>&#13;
					</tr>&#13;
				</table>&#13;
			</div>&#13;
		</div>&#13;
&#13;

<p>N’oubliez pas de modifier le numéro de version après la création de la branche !</p>
<p>Ensuite, corrigez le bug et enregistrez le correctif dans un ou plusieurs commits séparés.</p>
&#13;
&#13;
		<div id="crayon-5524f18329a40868633621" class="crayon-syntax crayon-theme-github crayon-font-monaco crayon-os-pc print-yes notranslate" data-settings=" minimize scroll-mouseover">&#13;
		&#13;
			&#13;
			<p class="crayon-info"/>&#13;
			<p class="crayon-plain-wrap"/>&#13;
			<div class="crayon-main">&#13;
				<table class="crayon-table">&#13;
					<tr class="crayon-row">&#13;
				<td class="crayon-nums " data-settings="show">&#13;
					&#13;
				</td>&#13;
						<td class="crayon-code"><div class="crayon-pre"><p class="crayon-line" id="crayon-5524f18329a40868633621-1"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">commit</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">m</span><span class="crayon-h"> </span><span class="crayon-s">"Fixed severe production problem"</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a40868633621-2"><span class="crayon-sy">[</span><span class="crayon-i">hotfix</span><span class="crayon-o">-</span><span class="crayon-cn">1.2.1</span><span class="crayon-h"> </span><span class="crayon-i">abbe5d6</span><span class="crayon-sy">]</span><span class="crayon-h"> </span><span class="crayon-e">Fixed </span><span class="crayon-e">severe </span><span class="crayon-e">production </span><span class="crayon-i">problem</span></p><p class="crayon-line" id="crayon-5524f18329a40868633621-3"><span class="crayon-cn">5</span><span class="crayon-h"> </span><span class="crayon-e">files </span><span class="crayon-i">changed</span><span class="crayon-sy">,</span><span class="crayon-h"> </span><span class="crayon-cn">32</span><span class="crayon-h"> </span><span class="crayon-e">insertions</span><span class="crayon-sy">(</span><span class="crayon-o">+</span><span class="crayon-sy">)</span><span class="crayon-sy">,</span><span class="crayon-h"> </span><span class="crayon-cn">17</span><span class="crayon-h"> </span><span class="crayon-e">deletions</span><span class="crayon-sy">(</span><span class="crayon-o">-</span><span class="crayon-sy">)</span></p></div></td>&#13;
					</tr>&#13;
				</table>&#13;
			</div>&#13;
		</div>&#13;
&#13;

<h3>Finalisation d’une branche de correctif</h3>
<p>Lorsque c’est terminé, le correctif a besoin d’être reporté dans  &#13;
			<span id="crayon-5524f18329a43970059185" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span>, mais aussi dans &#13;
			<span id="crayon-5524f18329a46627426476" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span>, de manière à garantir que le correctif sera également inclus dans la prochaine version. C’est en tout point similaire à la manière dont les branches de version sont finalisées.</p>
<p>Premièrement, mettez à jour &#13;
			<span id="crayon-5524f18329a49199068534" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">master</span></span></span> et taguez la version :</p>
&#13;
&#13;
		<div id="crayon-5524f18329a4c435859100" class="crayon-syntax crayon-theme-github crayon-font-monaco crayon-os-pc print-yes notranslate" data-settings=" minimize scroll-mouseover">&#13;
		&#13;
			&#13;
			<p class="crayon-info"/>&#13;
			<p class="crayon-plain-wrap"/>&#13;
			<div class="crayon-main">&#13;
				<table class="crayon-table">&#13;
					<tr class="crayon-row">&#13;
				<td class="crayon-nums " data-settings="show">&#13;
					&#13;
				</td>&#13;
						<td class="crayon-code"><div class="crayon-pre"><p class="crayon-line" id="crayon-5524f18329a4c435859100-1"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-e">checkout </span><span class="crayon-e">master</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a4c435859100-2"><span class="crayon-e">Switched </span><span class="crayon-st">to</span><span class="crayon-h"> </span><span class="crayon-i">branch</span><span class="crayon-h"> </span><span class="crayon-s">'master'</span></p><p class="crayon-line" id="crayon-5524f18329a4c435859100-3"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">merge</span><span class="crayon-h"> </span><span class="crayon-o">--</span><span class="crayon-i">no</span><span class="crayon-o">-</span><span class="crayon-e">ff </span><span class="crayon-i">hotfix</span><span class="crayon-o">-</span><span class="crayon-cn">1.2.1</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a4c435859100-4"><span class="crayon-e">Merge </span><span class="crayon-e">made </span><span class="crayon-e">by </span><span class="crayon-i">recursive</span><span class="crayon-sy">.</span></p><p class="crayon-line" id="crayon-5524f18329a4c435859100-5"><span class="crayon-sy">(</span><span class="crayon-cn">R</span>é<span class="crayon-i">sum</span>é<span class="crayon-h"> </span><span class="crayon-e">des </span><span class="crayon-i">modifications</span><span class="crayon-sy">)</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a4c435859100-6"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">tag</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">a</span><span class="crayon-h"> </span><span class="crayon-cn">1.2.1</span></p></div></td>&#13;
					</tr>&#13;
				</table>&#13;
			</div>&#13;
		</div>&#13;
&#13;

<p>Remarque : Vous pouvez tout aussi bien vouloir utiliser les options &#13;
			<span id="crayon-5524f18329a4f136312351" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-o">-</span><span class="crayon-i">s</span></span></span> or &#13;
			<span id="crayon-5524f18329a52489059065" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-o">-</span><span class="crayon-i">u</span></span></span> &#13;
			<span id="crayon-5524f18329a55688246346" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-o">&lt;</span><span class="crayon-i">clef</span><span class="crayon-o">&gt;</span></span></span> pour signer votre tag de manière chiffrée.</p>
<p>Ensuite, déployez également le correctif dans &#13;
			<span id="crayon-5524f18329a58834630723" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span> :</p>
&#13;
&#13;
		<div id="crayon-5524f18329a5b304708732" class="crayon-syntax crayon-theme-github crayon-font-monaco crayon-os-pc print-yes notranslate" data-settings=" minimize scroll-mouseover">&#13;
		&#13;
			&#13;
			<p class="crayon-info"/>&#13;
			<p class="crayon-plain-wrap"/>&#13;
			<div class="crayon-main">&#13;
				<table class="crayon-table">&#13;
					<tr class="crayon-row">&#13;
				<td class="crayon-nums " data-settings="show">&#13;
					&#13;
				</td>&#13;
						<td class="crayon-code"><div class="crayon-pre"><p class="crayon-line" id="crayon-5524f18329a5b304708732-1"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-e">checkout </span><span class="crayon-e">develop</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a5b304708732-2"><span class="crayon-e">Switched </span><span class="crayon-st">to</span><span class="crayon-h"> </span><span class="crayon-i">branch</span><span class="crayon-h"> </span><span class="crayon-s">'develop'</span></p><p class="crayon-line" id="crayon-5524f18329a5b304708732-3"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">merge</span><span class="crayon-h"> </span><span class="crayon-o">--</span><span class="crayon-i">no</span><span class="crayon-o">-</span><span class="crayon-e">ff </span><span class="crayon-i">hotfix</span><span class="crayon-o">-</span><span class="crayon-cn">1.2.1</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a5b304708732-4"><span class="crayon-e">Merge </span><span class="crayon-e">made </span><span class="crayon-e">by </span><span class="crayon-i">recursive</span><span class="crayon-sy">.</span></p><p class="crayon-line" id="crayon-5524f18329a5b304708732-5"><span class="crayon-sy">(</span><span class="crayon-cn">R</span>é<span class="crayon-i">sum</span>é<span class="crayon-h"> </span><span class="crayon-e">des </span><span class="crayon-i">modifications</span><span class="crayon-sy">)</span></p></div></td>&#13;
					</tr>&#13;
				</table>&#13;
			</div>&#13;
		</div>&#13;
&#13;

<p>La seule exception à la règle ici est que, <strong>lorsqu’une branche de version en cours de developpement existe, le correctif a besoin d’être reporté dans cette branche de version, plutôt que dans &#13;
			<span id="crayon-5524f18329a5e753088104" class="crayon-syntax crayon-syntax-inline  crayon-theme-github crayon-theme-github-inline crayon-font-monaco"><span class="crayon-pre crayon-code"><span class="crayon-i">develop</span></span></span></strong>. Le report de l’anomalie dans la branche de version finira par être reporté dans develop à son tour, lorsque la branche de version sera terminée. (Si le travail en cours sur develop nécessite que l’anomalie soit corrigée immédiatement sans attendre la fin de la branche de version, vous pouvez tout aussi bien reporter dès à présent le correctif également sur develop.)</p>
<p>Enfin, supprimer la branche temporaire :</p>
&#13;
&#13;
		<div id="crayon-5524f18329a61407983306" class="crayon-syntax crayon-theme-github crayon-font-monaco crayon-os-pc print-yes notranslate" data-settings=" minimize scroll-mouseover">&#13;
		&#13;
			&#13;
			<p class="crayon-info"/>&#13;
			<p class="crayon-plain-wrap"/>&#13;
			<div class="crayon-main">&#13;
				<table class="crayon-table">&#13;
					<tr class="crayon-row">&#13;
				<td class="crayon-nums " data-settings="show">&#13;
					&#13;
				</td>&#13;
						<td class="crayon-code"><div class="crayon-pre"><p class="crayon-line" id="crayon-5524f18329a61407983306-1"><span class="crayon-sy">$</span><span class="crayon-h"> </span><span class="crayon-e">git </span><span class="crayon-i">branch</span><span class="crayon-h"> </span><span class="crayon-o">-</span><span class="crayon-i">d</span><span class="crayon-h"> </span><span class="crayon-i">hotfix</span><span class="crayon-o">-</span><span class="crayon-cn">1.2.1</span></p><p class="crayon-line crayon-striped-line" id="crayon-5524f18329a61407983306-2"><span class="crayon-e">Deleted </span><span class="crayon-e">branch </span><span class="crayon-i">hotfix</span><span class="crayon-o">-</span><span class="crayon-cn">1.2.1</span><span class="crayon-h"> </span><span class="crayon-sy">(</span><span class="crayon-e">was </span><span class="crayon-i">abbe5d6</span><span class="crayon-sy">)</span><span class="crayon-sy">.</span></p></div></td>&#13;
					</tr>&#13;
				</table>&#13;
			</div>&#13;
		</div>&#13;
&#13;

<h2>En résumé</h2>
<p>Bien qu’il n’y ait rien de bien révolutionnaire dans ce modèle de développement, l’illustration qui figure au début de cet article s’est révélée particulièrement utile dans nos projets. C’est un modèle mental facile à appréhender et il permet de développer une appropriation collective des processus de branches et de versions.</p>
<p>Enfin, voici <a href="http://nvie.com/files/Git-branching-model.pdf">une version PDF en haute résolution du modèle</a>. Imprimez-le et accrochez le au mur pour avoir une référence sous les yeux à tout moment.</p>
<p><em>NdT : Pour aller plus loin, nous vous recommandons de lire <a href="http://jeffkreeftmeijer.com/2010/why-arent-you-using-git-flow/" title="Why aren't you using Gitflow?">cette introduction à Gitflow</a>, dont le but est de vous aider à suivre ce modèle de développement. Il existe d’autres workflows Git que vous pouvez tester comme le <a href="https://guides.github.com/introduction/flow/index.html" title="Comprendre le Github Flow (anglais)">Github Flow</a>, le <a href="https://about.gitlab.com/2014/09/29/gitlab-flow/">Gitlab Flow</a>, celui <a href="http://fbrnc.net/blog/2014/12/keeping-it-simple-git-workflow" title="Keepiing it simple Git Workflow (en anglais)">utilisé chez AOE</a> ou cette <a href="https://www.atlassian.com/git/tutorials/comparing-workflows" title="Comparing Workflows (en anglais)">comparaison de workflow chez Atlasssian</a>, l’essentiel étant de l’adapter à votre contexte et à votre équipe.</em></p>
